/**
 *******************************************************************************
 * @file    tmpm066_i2cs.h
 * @brief   This file provides all the functions prototypes for I2CS driver.
 * @version V2.0.2.1
 * @date    2015/10/21
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM066_I2CS_H
#define __TMPM066_I2CS_H


#ifdef __cplusplus
extern "C" {
#endif  /*__cplusplus*/

/* Includes ------------------------------------------------------------------*/
#include "TMPM066.h"
#include "tx00_common.h"

#if defined(__TMPM066_I2CS_H)
/** @addtogroup TX00_Periph_Driver
  * @{
  */

/** @addtogroup I2CS
  * @{
  */

/** @defgroup I2CS_Exported_Types
  * @{
  */
    typedef union {
        uint8_t All;
        struct {
            uint8_t  INTRelease:1; 
            uint8_t  GeneralCallDet:1;
            uint8_t  Reserved:1;    
            uint8_t  TRx:1;            	        	            	       	
            uint8_t  I2RES:1;
            uint8_t  ARK:1;
            uint8_t  GeneralCall:1; 
            uint8_t  StopStart:1;
        } Bit;
    } I2CS_State;  
  
    typedef union {
        uint8_t All;
        struct {
            uint8_t  Reserved1:1; 
            uint8_t  Match1stSlaveAdd:1;
            uint8_t  Match2ndSlaveAdd:1;    
            uint8_t  Reserved2:5;            	        	            	       	
        } Bit;
    } I2CS_MatchAdd;   
  
 

/** @} */
/* End of group I2CS_Exported_Types */

/** @defgroup I2CS_Exported_Macros 
  * @{
  */
#define IS_I2CS_DATA(param)             ((param) <= (uint8_t)0x7F) 

/** @} */
/* End of group I2CS_Exported_Macros */

/** @defgroup I2CS_Exported_FunctionPrototypes
  * @{
  */
    void I2CS_SetACK(FunctionalState NewState); 
    void I2CS_Reset(FunctionalState NewState);
    void I2CS_INTRelease(FunctionalState NewState);
    I2CS_State I2CS_GetState(void);
    void I2CS_Set2ndSlaveAddState(FunctionalState NewState);  
    I2CS_MatchAdd I2CS_GetMatchAddState(void);    
    void I2CS_Set1stSlaveAdd(uint8_t Data);
    uint8_t I2CS_Get1stSlaveAdd(void);
    void I2CS_Set2ndSlaveAdd(uint8_t Data);
    uint8_t I2CS_Get2ndSlaveAdd(void); 
    
/* End of group I2CS_Exported_FunctionPrototypes */

/** @} */
/* End of group I2CS */

/** @} */
/* End of group TX00_Periph_Driver */
#endif                          /* defined(__TMPM066_I2CS_H) */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM066_I2CS_H */
