/**
 *******************************************************************************
 * @file    tmpm066_lvd.h
 * @brief   This file provides all the functions prototypes for LVD driver. 
 * @version V2.0.2.1
 * @date    2015/10/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM066_LVD_H
#define __TMPM066_LVD_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM066.h"
#include "tx00_common.h"

#if defined(__TMPM066_LVD_H)
/** @addtogroup TX00_Periph_Driver
  * @{
  */

/** @addtogroup LVD
  * @{
  */

/** @defgroup LVD_Exported_Types
  * @{
  */
    typedef enum {
        LVD_VD_UPPER = 0U,
        LVD_VD_LOWER = 1U
    } LVD_VDStatus;

/** @} */
/* End of group LVD_Exported_Types */

/** @defgroup LVD_Exported_Constants
  * @{
  */
#define LVD_VDLVL1_200                   ((uint32_t)0x00000008)
#define LVD_VDLVL1_210                   ((uint32_t)0x0000000A)
#define IS_LVD_VD1_LEVEL(param)         (((param) == LVD_VDLVL1_200) || \
                                         ((param) == LVD_VDLVL1_210))
                                         
#define LVD_VDLVL2_220                   ((uint32_t)0x00000000)
#define LVD_VDLVL2_230                   ((uint32_t)0x00000002)
#define LVD_VDLVL2_240                   ((uint32_t)0x00000004)
#define LVD_VDLVL2_250                   ((uint32_t)0x00000006)
#define LVD_VDLVL2_260                   ((uint32_t)0x00000008)
#define LVD_VDLVL2_270                   ((uint32_t)0x0000000A)
#define LVD_VDLVL2_280                   ((uint32_t)0x0000000C)
#define LVD_VDLVL2_290                   ((uint32_t)0x0000000E)
#define IS_LVD_VD2_LEVEL(param)         (((param) == LVD_VDLVL2_220) || \
                                         ((param) == LVD_VDLVL2_230) || \
                                         ((param) == LVD_VDLVL2_240) || \
                                         ((param) == LVD_VDLVL2_250) || \
                                         ((param) == LVD_VDLVL2_260) || \
                                         ((param) == LVD_VDLVL2_270) || \
                                         ((param) == LVD_VDLVL2_280) || \
                                         ((param) == LVD_VDLVL2_290))                                         

#define LVD_INTSEL_LOWER                ((uint32_t)0x00000000)
#define LVD_INTSEL_LOWER_UPPER          ((uint32_t)0x00000010)
#define IS_LVD_INT_CONDITION(param)     (((param) == LVD_INTSEL_LOWER) || \
                                         ((param) == LVD_INTSEL_LOWER_UPPER))
/** @} */
/* End of LVD_Exported_Constants */

/** @defgroup LVD_Exported_FunctionPrototypes
  * @{
  */
    void LVD_EnableVD1(void);
    void LVD_DisableVD1(void);
    void LVD_SetVD1Level(uint32_t VDLevel);
    LVD_VDStatus LVD_GetVD1Status(void);
    void LVD_EnableVD2(void);
    void LVD_DisableVD2(void);
    void LVD_SetVD2Level(uint32_t VDLevel);
    LVD_VDStatus LVD_GetVD2Status(void);    
    void LVD_SetVD1ResetOutput(FunctionalState NewState);
    void LVD_SetVD1INTOutput(FunctionalState NewState);
    uint32_t LVD_GetVD1INTCondition(void);
    void LVD_SetVD2ResetOutput(FunctionalState NewState);
    void LVD_SetVD2INTOutput(FunctionalState NewState);    
    uint32_t LVD_GetVD2INTCondition(void);
    
/** @} */
/* End of LVD_Exported_FunctionPrototypes */

/** @} */
/* End of group LVD */

/** @} */
/* End of group TX00_Periph_Driver */
#endif                          /* defined(__TMPM066_LVD_H) */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM066_LVD_H */
