/**
 *******************************************************************************
 * @file    tmpm066_tmrd.h
 * @brief   This file provides all the functions prototypes for TMRD driver.
 * @version V2.0.2.1
 * @date    2015/09/15
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM066_TMRD_H
#define __TMPM066_TMRD_H

#ifdef __cplusplus
extern "C" {
#endif                          /* __cplusplus */

/* Includes ------------------------------------------------------------------*/
#include "TMPM066.h"
#include "tx00_common.h"

/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @addtogroup TMRD
  * @{
  */

/** @defgroup TMRD_Exported_Types
  * @{
  */

/**
  * @brief TMRD Timing Structure definition
  */
    typedef struct {
        uint16_t Cycle;
        uint16_t LeadingTiming0;
        uint16_t TrailingTiming0;
        uint8_t BitModulationRate0;
        uint16_t LeadingTiming1;
        uint16_t TrailingTiming1;
        uint16_t PhaseShiftTiming;
        uint8_t BitModulationRate1;
    } TMRD_TimingTypeDef;

/**
  * @brief TMRD Unit Channel Enumeration definition
  */
    typedef enum {
        TMRD_UNIT_CH_0 = 0U,
        TMRD_UNIT_CH_1 = 1U
    } TMRD_UNIT_Channel;

    typedef enum {
        TMRD_UNIT_PH_0 = 0U,
        TMRD_UNIT_PH_1 = 1U
    } TMRD_UNIT_Phase;

/** @} */
/* End of group TMRD_Exported_Types */


/** @defgroup TMRD_Exported_Constants
  * @{
  */
#define IS_TMRD_ALL_CHANNEL(param)                  (((param) == TMRD_UNIT_CH_0) || ((param) == TMRD_UNIT_CH_1))
#define IS_TMRD_ALL_PHASE(param)                    (((param) == TMRD_UNIT_PH_0) || ((param) == TMRD_UNIT_PH_1))

#define TMRD_LOUT_HSW_CCW_CW                        ((uint8_t)0x00U)
#define TMRD_LOUT_HSW_BRAKE                         ((uint8_t)0x01U)
#define TMRD_LOUT_HSW_STOP                          ((uint8_t)0x02U)
#define IS_TMRD_LOUT_HSW_MODE(param)                (((param) == TMRD_LOUT_HSW_CCW_CW) || \
                                                     ((param) == TMRD_LOUT_HSW_BRAKE) ||\
                                                     ((param) == TMRD_LOUT_HSW_STOP))

#define TMRD_RUN                                    ((uint8_t)0x00U)
#define TMRD_STOP                                   ((uint8_t)0x01U)
#define IS_TMRD_RUN_STATE(param)                    ((param) <= TMRD_STOP)

#define TMRD_MODE_BOTH_TMR                          ((uint8_t)0x00U)
#define TMRD_MODE_0TMR_1PPG                         ((uint8_t)0x01U)
#define TMRD_MODE_0PPG_1TMR                         ((uint8_t)0x02U)
#define TMRD_MODE_BOTH_PPG                          ((uint8_t)0x03U)
#define TMRD_MODE_INTERLOCK_TMR                     ((uint8_t)0x04U)
#define TMRD_MODE_INTERLOCK_PPG_2CH                 ((uint8_t)0x06U)
#define TMRD_MODE_INTERLOCK_PPG_3CH                 ((uint8_t)0x07U)
#define IS_TMRD_MODE(param)                         (((param) == TMRD_MODE_BOTH_TMR) || \
                                                     ((param) == TMRD_MODE_0TMR_1PPG) || \
                                                     ((param) == TMRD_MODE_0PPG_1TMR) || \
                                                     ((param) == TMRD_MODE_BOTH_PPG) || \
                                                     ((param) == TMRD_MODE_INTERLOCK_TMR) || \
                                                     ((param) == TMRD_MODE_INTERLOCK_PPG_2CH) || \
                                                     ((param) == TMRD_MODE_INTERLOCK_PPG_3CH))

#define TMRD_PPG_CHANNEL_00                         ((uint8_t)0x00U)
#define TMRD_PPG_CHANNEL_01                         ((uint8_t)0x01U)
#define TMRD_PPG_CHANNEL_10                         ((uint8_t)0x02U)
#define TMRD_PPG_CHANNEL_11                         ((uint8_t)0x03U)
#define IS_TMRD_PPG_CHANNEL(param)                  ((param) <= TMRD_PPG_CHANNEL_11)

#define TMRD_WAVE_EDGE_RISING                       ((uint8_t)0x00U)
#define TMRD_WAVE_EDGE_FALLING                      ((uint8_t)0x01U)
#define IS_TMRD_WAVE_EDGE(param)                    ((param) <= TMRD_WAVE_EDGE_FALLING)

#define TMRD_FREE_RUN                               ((uint8_t)0x00U)
#define TMRD_AUTO_CLEAR                             ((uint8_t)0x01U)
#define IS_TMRD_UC_CTRL(param)                      ((param) <= TMRD_AUTO_CLEAR)

#define TMRD_CLK_DIV_1                              ((uint8_t)0x00U)
#define TMRD_CLK_DIV_2                              ((uint8_t)0x08U)
#define TMRD_CLK_DIV_4                              ((uint8_t)0x09U)
#define TMRD_CLK_DIV_8                              ((uint8_t)0x0AU)
#define TMRD_CLK_DIV_16                             ((uint8_t)0x0BU)
#define IS_TMRD_CLK_DIV(param)                      (((param) == TMRD_CLK_DIV_1) || \
                                                     ((param) == TMRD_CLK_DIV_2) || \
                                                     ((param) == TMRD_CLK_DIV_4) || \
                                                     ((param) == TMRD_CLK_DIV_8) || \
                                                     ((param) == TMRD_CLK_DIV_16))

#define TMRD_CMP_WRITE_DIRECT                       ((uint8_t)0x00U)
#define TMRD_CMP_WRITE_INDIRECT                     ((uint8_t)0x01U)
#define IS_TMRD_CMP_WRITE_PATH(param)               ((param) <= TMRD_CMP_WRITE_INDIRECT)

#define TMRD_INT_NONE                               ((uint8_t)0x00U)
#define TMRD_INT_MATCH_CYCLE                        ((uint8_t)0x01U)
#define TMRD_INT_MATCH_PHASE                        ((uint8_t)0x02U)
#define TMRD_INT_UC_OVERFLOW                        ((uint8_t)0x03U)
#define IS_TMRD_TD0_INT_SRC(param)                  ((param) <= TMRD_INT_UC_OVERFLOW)
#define IS_TMRD_TD1_INT_SRC(param)                  (((param) == TMRD_INT_NONE) || \
                                                     ((param) == TMRD_INT_MATCH_CYCLE) || \
                                                     ((param) == TMRD_INT_UC_OVERFLOW))

#define TMRD_1BITMOD_CYCLE_NONE                     ((uint8_t)0x00U)
#define TMRD_1BITMOD_CYCLE_2TIMES                   ((uint8_t)0x01U)
#define TMRD_1BITMOD_CYCLE_4TIMES                   ((uint8_t)0x02U)
#define TMRD_1BITMOD_CYCLE_8TIMES                   ((uint8_t)0x03U)
#define TMRD_1BITMOD_CYCLE_16TIMES                  ((uint8_t)0x04U)
#define IS_TMRD_1BITMOD_CYCLE(param)                ((param) <= TMRD_1BITMOD_CYCLE_16TIMES)

#define TMRD_PHASE_DELAY_OR_SAME                    ((uint8_t)0x00U)
#define TMRD_PHASE_FAST_OR_SAME                     ((uint8_t)0x01U)
#define IS_TMRD_PHASE_RELATION(param)               (((param) == TMRD_PHASE_DELAY_OR_SAME) || \
                                                     ((param) == TMRD_PHASE_FAST_OR_SAME))

#define TMRD_UPDATE_CH_00                           ((uint8_t)0x01U)
#define TMRD_UPDATE_CH_01                           ((uint8_t)0x02U)
#define TMRD_UPDATE_CH_10                           ((uint8_t)0x04U)
#define TMRD_UPDATE_CH_11                           ((uint8_t)0x08U)
#define IS_TMRD_UPDATE_CH(param)                    ((param) <= 0x0FU)

#define TMRD_TIMING_TD0_CYCLE                       ((uint8_t)0x00U)
#define TMRD_TIMING_00_LEADING                      ((uint8_t)0x01U)
#define TMRD_TIMING_00_TRAILING                     ((uint8_t)0x02U)
#define TMRD_TIMING_01_LEADING                      ((uint8_t)0x03U)
#define TMRD_TIMING_01_TRAILING                     ((uint8_t)0x04U)
#define TMRD_TIMING_PHASE_SHIFT                     ((uint8_t)0x05U)
#define TMRD_TIMING_TD1_CYCLE                       ((uint8_t)0x06U)
#define TMRD_TIMING_10_LEADING                      ((uint8_t)0x07U)
#define TMRD_TIMING_10_TRAILING                     ((uint8_t)0x08U)
#define TMRD_TIMING_11_LEADING                      ((uint8_t)0x09U)
#define TMRD_TIMING_11_TRAILING                     ((uint8_t)0x0AU)
#define IS_TMRD_TIMING_TYPE(param)                  ((param) <= TMRD_TIMING_11_TRAILING)

#define TMRD_LOW_LEVEL                              ((uint8_t)0x00U)
#define TMRD_HIGH_LEVEL                             ((uint8_t)0x01U)
#define IS_TMRD_LEVEL(param)                        (((param) == TMRD_LOW_LEVEL) || \
                                                     ((param) == TMRD_HIGH_LEVEL))

/** @} */
/* End of group TMRD_Exported_Constants */
/** @defgroup TMRD_Exported_FunctionPrototypes
  * @{
  */

    void TMRD_Enable(TMRD_UNIT_Channel CHx);
    void TMRD_Disable(TMRD_UNIT_Channel CHx);
    void TMRD_SetRunStateInHalt(uint8_t RunState);
    void TMRD_SetRunStateInIdle(TMRD_UNIT_Channel CHx, uint8_t RunState);
    void TMRD_SetMode(uint8_t Mode);
    void TMRD_SetClkDivision(TMRD_UNIT_Channel CHx, uint8_t ClkDiv);
    void TMRD_SetUpCntCtrl(TMRD_UNIT_Channel CHx, uint8_t UpCntCtrl);
    void TMRD_SetPPGInitLeadingEdge(uint8_t PPGChannel, uint8_t WaveEdge);
    void TMRD_SetCMPRegWritePath(TMRD_UNIT_Channel CHx, uint8_t WritePath);
    void TMRD_SetCMP0INTSrc(TMRD_UNIT_Channel CHx, uint8_t INTSrc);
    void TMRD_SetBitModulationCycle(uint8_t PPGChannel, uint8_t BitModCycle);
    void TMRD_SetBitModUpdateTiming(uint8_t PPGChannel,
                                    FunctionalState NewState);
    void TMRD_SetRunState(TMRD_UNIT_Channel CHx, uint8_t RunState);
    void TMRD_SetPhaseRelation(uint8_t PhaseRelation);
    void TMRD_EnableUpdateCMPReg(uint8_t UpdateCHx);
    void TMRD_SetDMAReq(TMRD_UNIT_Channel CHx, FunctionalState NewState);
    void TMRD_SetInitTiming(TMRD_UNIT_Channel CHx,
                            TMRD_TimingTypeDef * TimingStruct);
    void TMRD_ChangeTiming(uint8_t TimingType, uint16_t Timing);
    uint16_t TMRD_GetTiming(uint8_t TimingType);
    void TMRD_SetLOutHSWMode(TMRD_UNIT_Channel CHx,
                             TMRD_UNIT_Phase PHx, uint8_t LMode);
    uint8_t TMRD_GetLOutHSWMode(TMRD_UNIT_Channel CHx, TMRD_UNIT_Phase PHx);
    void TMRD_EnableHSWMode(TMRD_UNIT_Channel CHx, TMRD_UNIT_Phase PHx);
    void TMRD_DisableHSWMode(TMRD_UNIT_Channel CHx, TMRD_UNIT_Phase PHx);
    FunctionalState TMRD_GetHSWModeState(TMRD_UNIT_Channel CHx,
                                         TMRD_UNIT_Phase PHx);
    void TMRD_SetTDDIRLevel(TMRD_UNIT_Channel CHx, TMRD_UNIT_Phase PHx,
                            uint8_t Level);
    uint8_t TMRD_GetTDDIRLevel(TMRD_UNIT_Channel CHx, TMRD_UNIT_Phase PHx);

/** @} */
/* End of group TMRD_Exported_FunctionPrototypes */

/** @} */
/* End of group TMRD */

/** @} */
/* End of group TX03_Periph_Driver */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM066_TMRD_H */
