/**
 *******************************************************************************
 * @file    tmpm066_udmac.h
 * @brief   This file provides all the functions prototypes for uDMAC driver.
 * @version V2.0.2.1
 * @date    2015/09/11
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM066_uDMAC_H
#define __TMPM066_uDMAC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM066.h"
#include "TX00_common.h"

/** @addtogroup TX04_Periph_Driver
  * @{
  */

/** @addtogroup uDMAC
  * @{
  */

/** @defgroup uDMAC_Exported_Types
  * @{
  */

/*DMAC  channels*/
#define DMAC_UART0_RX                    ((uint8_t)0x00)
#define DMAC_UART0_TX                    ((uint8_t)0x01)
#define DMAC_UART1_RX                    ((uint8_t)0x02)
#define DMAC_UART1_TX                    ((uint8_t)0x03)
#define DMAC_I2C0_RX                     ((uint8_t)0x04)
#define DMAC_I2C0_TX                     ((uint8_t)0x05)
#define DMAC_I2C1_TX                     ((uint8_t)0x06)
#define DMAC_I2C1_RX                     ((uint8_t)0x07)
#define DMAC_TSPI_RX                     ((uint8_t)0x08)
#define DMAC_TSPI_TX                     ((uint8_t)0x09)
#define DMAC_TMRB0_CMP_MATCH             ((uint8_t)0x0A)
#define DMAC_TMRB1_CMP_MATCH             ((uint8_t)0x0B)
#define DMAC_TMRB2_CMP_MATCH             ((uint8_t)0x0C)
#define DMAC_TMRB3_CMP_MATCH             ((uint8_t)0x0D)
#define DMAC_TMRB4_CMP_MATCH             ((uint8_t)0x0E)
#define DMAC_TMRB5_CMP_MATCH             ((uint8_t)0x0F)
#define DMAC_TMRB6_CMP_MATCH             ((uint8_t)0x10)
#define DMAC_TMRB7_CMP_MATCH             ((uint8_t)0x11)
#define DMAC_TMRB0_INPUT_CAP0            ((uint8_t)0x12)
#define DMAC_TMRB1_INPUT_CAP0            ((uint8_t)0x13)
#define DMAC_TMRB2_INPUT_CAP0            ((uint8_t)0x14)
#define DMAC_TMRB3_INPUT_CAP0            ((uint8_t)0x15)
#define DMAC_TMRB4_INPUT_CAP0            ((uint8_t)0x16)
#define DMAC_TMRB5_INPUT_CAP0            ((uint8_t)0x17)
#define DMAC_TMRB6_INPUT_CAP0            ((uint8_t)0x18)
#define DMAC_TMRB7_INPUT_CAP0            ((uint8_t)0x19)
#define DMAC_TOP_PRIORITY_ADC            ((uint8_t)0x1E)
#define DMAC_ADC_COMPLETION              ((uint8_t)0x1F)

#define IS_DMAC_CHANNEL_ALL(param)       ((param) <= DMAC_ADC_COMPLETION)

    typedef enum {
        DMAC_PRIMARY = 0U,
        DMAC_ALTERNATE = 1U
    } DMAC_PrimaryAlt;
#define IS_DMAC_PRIMARYALT(param)         ((param) <= DMAC_ALTERNATE)
#define IS_DMAC_CTRL_BASE(param)          (((param) & (uint32_t)0x000003FF) == (uint32_t)0x00000000)

    typedef enum {
        DMAC_SINGLE = 0U,
        DMAC_BURST = 1U
    } DMAC_TransferType;
#define IS_DMAC_TRANSFERTYPE(param)       ((param) <= DMAC_BURST)

    typedef enum {
        DMAC_PRIOTIRY_NORMAL = 0U,
        DMAC_PRIOTIRY_HIGH = 1U
    } DMAC_Priority;
#define IS_DMAC_PRIORITY(param)           ((param) <= DMAC_PRIOTIRY_HIGH)


    typedef enum {
        DMAC_BYTE = 0U,         /* data size of transfer is 1 byte */
        DMAC_HALF_WORD = 1U,    /* data size of transfer is 2 bytes */
        DMAC_WORD = 2U          /* data size of transfer is 4 bytes */
    } DMAC_BitWidth;
#define IS_DMAC_BIT_WIDTH(param)          ((param) <= DMAC_WORD)

    typedef enum {
        DMAC_INC_1B = 0U,       /* address increment 1 byte */
        DMAC_INC_2B = 1U,       /* address increment 2 bytes */
        DMAC_INC_4B = 2U,       /* address increment 4 bytes */
        DMAC_INC_0B = 3U        /* address does not increase */
    } DMAC_IncWidth;
#define IS_DMAC_INCWIDTH(param)           ((param) <= DMAC_INC_0B)
#define IS_DMAC_INCWIDTH_VALID(bitwidth, incwidth)     ((bitwidth) <= (incwidth))

    typedef enum {
        DMAC_INVALID = 0U,
        DMAC_BASIC = 1U,
        DMAC_AUTOMATIC = 2U,
        DMAC_PINGPONG = 3U,
        DMAC_MEM_SCATTER_GATHER_PRI = 4U,       /* Memory scatter/gather mode (primary data) */
        DMAC_MEM_SCATTER_GATHER_ALT = 5U,       /* Memory scatter/gather mode (alternative data) */
        DMAC_PERI_SCATTER_GATHER_PRI = 6U,      /* Peripheral scatter/gather mode (primary data) */
        DMAC_PERI_SCATTER_GATHER_ALT = 7U       /* Peripheral scatter/gather mode (alternative data) */
    } DMAC_CycleCtrl;
#define IS_DMAC_CYCLECTRL(param)          ((param) <= DMAC_PERI_SCATTER_GATHER_ALT)

    typedef enum {
        DMAC_NEXT_NOT_USE_BURST = 0U,
        DMAC_NEXT_USE_BURST = 1U
    } DMAC_Next_UseBurst;
#define IS_DMAC_NEXT_USEBURST(param)      ((param) <= DMAC_NEXT_USE_BURST)

    typedef enum {
        DMAC_AFTER_1_TX = 0U,   /* Arbitration after one transfer */
        DMAC_AFTER_2_TX = 1U,   /* Arbitration after two transfer */
        DMAC_AFTER_4_TX = 2U,
        DMAC_AFTER_8_TX = 3U,
        DMAC_AFTER_16_TX = 4U,
        DMAC_AFTER_32_TX = 5U,
        DMAC_AFTER_64_TX = 6U,
        DMAC_AFTER_128_TX = 7U,
        DMAC_AFTER_256_TX = 8U,
        DMAC_AFTER_512_TX = 9U, /* Arbitration after 512 transfer */
        DMAC_NEVER = 10U        /* Do not arbitration */
    } DMAC_Arbitration;
#define IS_DMAC_ARBITRATION(param)        ((param) <= DMAC_NEVER)

#define IS_DMAC_TXNUM(param)              ((param) <= 1024U)

/** 
  * @brief  Union to store DMA UINTA interrupt
  */
    typedef union {
        uint32_t All;
        struct {
            uint32_t UART0Reception:1;  /*!< bit0, the flag of UART0 reception occurs an interrupt */
            uint32_t UART0Transmission:1;       /*!< bit1, the flag of UART0 transmission occurs an interrupt */
            uint32_t UART1Reception:1;  /*!< bit2, the flag of UART1 reception occurs an interrupt */
            uint32_t UART1Transmission:1;       /*!< bit3, the flag of UART1 transmission occurs an interrupt */
            uint32_t I2C0Rx:1;  /*!< bit4, the flag of I2C0 reception occurs an interrupt */
            uint32_t I2C0Tx:1;  /*!< bit5, the flag of I2C0 transmission occurs an interrupt */
            uint32_t I2C1Rx:1;  /*!< bit6, the flag of I2C1 reception occurs an interrupt */
            uint32_t I2C1Tx:1;  /*!< bit7, the flag of I2C1 transmission occurs an interrupt */
            uint32_t TSPIReception:1;   /*!< bit8, the flag of TSPI reception occurs an interrupt */
            uint32_t TSPITransmission:1;        /*!< bit9, the flag of TSPI transmission occurs an interrupt */
            uint32_t TMRB0CompareMatch:1;       /*!< bit10, the flag of TMRB0 compare match occurs an interrupt */
            uint32_t TMRB1CompareMatch:1;       /*!< bit11, the flag of TMRB1 compare match occurs an interrupt */
            uint32_t TMRB2CompareMatch:1;       /*!< bit12, the flag of TMRB2 compare match occurs an interrupt */
            uint32_t TMRB3CompareMatch:1;       /*!< bit13, the flag of TMRB3 compare match occurs an interrupt */
            uint32_t TMRB4CompareMatch:1;       /*!< bit14, the flag of TMRB4 compare match occurs an interrupt */
            uint32_t TMRB5CompareMatch:1;       /*!< bit15, the flag of TMRB5 compare match occurs an interrupt */
            uint32_t TMRB6CompareMatch:1;       /*!< bit16, the flag of TMRB6 compare match occurs an interrupt */
            uint32_t TMRB7CompareMatch:1;       /*!< bit17, the flag of TMRB7 compare match occurs an interrupt */
            uint32_t TMRB0InputCapture0:1;      /*!< bit18, the flag of TMRB0 input capture 0 occurs an interrupt */
            uint32_t TMRB1InputCapture0:1;      /*!< bit19, the flag of TMRB1 input capture 0 occurs an interrupt */
            uint32_t TMRB2InputCapture0:1;      /*!< bit20, the flag of TMRB2 input capture 0 occurs an interrupt */
            uint32_t TMRB3InputCapture0:1;      /*!< bit21, the flag of TMRB3 input capture 0 occurs an interrupt */
            uint32_t TMRB4InputCapture0:1;      /*!< bit22, the flag of TMRB4 input capture 0 occurs an interrupt */
            uint32_t TMRB5InputCapture0:1;      /*!< bit23, the flag of TMRB5 input capture 0 occurs an interrupt */
            uint32_t TMRB6InputCapture0:1;      /*!< bit24, the flag of TMRB6 input capture 0 occurs an interrupt */
            uint32_t TMRB7InputCapture1:1;      /*!< bit25, the flag of TMRB7 input capture 0 occurs an interrupt */
            uint32_t Reserved:4;       	        /*!< bit26 to bit 30, reserved */
            uint32_t TOPADCCompletion:1;        /*!< bit31, the flag of TOP ADC completion occurs an interrupt */
            uint32_t ADCCompletion:1;           /*!< bit32, the flag of ADC completion occurs an interrupt */
        } Bit;
    } DMAC_Flag;

/** 
  * @brief  DMA Structure definition  
  */

    typedef struct {
        uint32_t SrcEndPointer; /*!< The final address of source */
        uint32_t DstEndPointer; /*!< The final address of destination */
        DMAC_CycleCtrl Mode;    /*!< Set operation mode */
        DMAC_Next_UseBurst NextUseBurst;
        uint32_t TxNum;         /*!< Set the actual number of transfers. max is 1024 */
        DMAC_Arbitration ArbitrationMoment;     /*!< Specifies the arbitration moment(R_Power)  */
        DMAC_BitWidth SrcWidth; /*!< Set source bit width */
        DMAC_IncWidth SrcInc;   /*!< Set increment of the source address */
        DMAC_BitWidth DstWidth; /*!< Set destination bit width */
        DMAC_IncWidth DstInc;   /*!< Set increment of the destination address */
    } DMAC_InitTypeDef;


/** @} */
/* End of group uDMAC_Exported_Types */

/** @defgroup uDMAC_Exported_FunctionPrototypes
  * @{
  */
    FunctionalState DMAC_GetDMACState(void);
    void DMAC_Enable(void);
    void DMAC_Disable(void);
    void DMAC_SetPrimaryBaseAddr(uint32_t Addr);
    uint32_t DMAC_GetBaseAddr(DMAC_PrimaryAlt PriAlt);
    void DMAC_SetSWReq(uint8_t Channel);
    void DMAC_SetTransferType(uint8_t Channel, DMAC_TransferType Type);
    DMAC_TransferType DMAC_GetTransferType(uint8_t Channel);
    void DMAC_SetMask(uint8_t Channel, FunctionalState NewState);
    FunctionalState DMAC_GetMask(uint8_t Channel);
    void DMAC_SetChannel(uint8_t Channel, FunctionalState NewState);
    FunctionalState DMAC_GetChannelState(uint8_t Channel);
    void DMAC_SetPrimaryAlt(uint8_t Channel, DMAC_PrimaryAlt PriAlt);
    DMAC_PrimaryAlt DMAC_GetPrimaryAlt(uint8_t Channel);
    void DMAC_SetChannelPriority(uint8_t Channel, DMAC_Priority Priority);
    DMAC_Priority DMAC_GetChannelPriority(uint8_t Channel);
    void DMAC_ClearBusErr(void);
    Result DMAC_GetBusErrState(void);
    void DMAC_FillInitData(uint8_t Channel, DMAC_InitTypeDef * InitStruct);
/** @} */
/* End of group uDMAC_Exported_FunctionPrototype */

/** @} */
/* End of group uDMAC */

/** @} */
/* End of group TX04_Periph_Driver */

#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM066_uDMAC_H */
