/**
 *******************************************************************************
 * @file    tmpm066_aoreg.c
 * @brief   This file provides API functions for AOREG driver 
 * @version V2.0.2.1    
 * @date    2015/09/22
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm066_aoreg.h"

#if defined(__TMPM066_AOREG_H)
/** @addtogroup TX00_Periph_Driver
  * @{
  */

/** @defgroup AOREG
  * @brief AOREG driver modules
  * @{
  */

/** @defgroup AOREG_Private_Defines
  * @{
  */
#define AO_RSTFLG_PORF_CLEAR           ((uint8_t)0xFE)
#define AO_RSTFLG_PINRSTF_CLEAR        ((uint8_t)0xF7)
#define AO_RSTFLG_LVDRSTF_CLEAR        ((uint8_t)0xDF)

#define AO_RSTFLG1_SYSRSTF_CLEAR       ((uint8_t)0xFE)
#define AO_RSTFLG1_WDTRSTF_CLEAR       ((uint8_t)0xFB)

#define AO_RESET_FLAG_MASK             ((uint8_t)0xD6)
#define AO_RESET_FLAG_MASK1            ((uint8_t)0xFA)

/** @} */
/* End of group AOREG_Private_Defines */

/** @defgroup AOREG_Private_FunctionPrototypes
  * @{
  */

/** @} */
/* End of group AOREG_Private_FunctionPrototypes */

/** @defgroup AOREG_Private_Functions
  * @{
  */

/** @} */
/* End of group AOREG_Private_Functions */

/** @defgroup AOREG_Exported_Functions
  * @{
  */

/**
  * @brief  Clear Power on reset flag.
  * @param  None
  * @retval None
  */
void AO_ClearPORFRSTF(void)
{
    TSB_AOREG->RSTFLG &= AO_RSTFLG_PORF_CLEAR;
}

/**
  * @brief  Clear PIN reset flag.
  * @param  None
  * @retval None
  */
void AO_ClearPINRSTF(void)
{
    TSB_AOREG->RSTFLG &= AO_RSTFLG_PINRSTF_CLEAR;
}

/**
  * @brief  Clear LVD reset flag.
  * @param  None
  * @retval None
  */
void AO_ClearLVDRSTF(void)
{
    TSB_AOREG->RSTFLG &= AO_RSTFLG_LVDRSTF_CLEAR;
}

/**
  * @brief  Clear SYSRESETREQ reset flag.
  * @param  None
  * @retval None
  */
void AO_ClearSYSRSTF(void)
{
    TSB_AOREG->RSTFLG1 &= AO_RSTFLG1_SYSRSTF_CLEAR;
}

/**
  * @brief  Clear WDT reset flag.
  * @param  None
  * @retval None
  */
void AO_ClearWDTRSTF(void)
{
    TSB_AOREG->RSTFLG1 &= AO_RSTFLG1_WDTRSTF_CLEAR;
}


/**
  * @brief  Get the type of AOREG reset reason and clear the reset flag.
  * @param  None
  * @retval Reset flag
  */
AO_ResetFlag AO_GetResetFlag(void)
{
    AO_ResetFlag reset_flag = { 0U };

    reset_flag.All = TSB_AOREG->RSTFLG & (~AO_RESET_FLAG_MASK);
    TSB_AOREG->RSTFLG = 0U;    
    return reset_flag;
}

/**
  * @brief  Get the type of AOREG reset reason and clear the reset flag.
  * @param  None
  * @retval Reset flag
  */
AO_ResetFlag1 AO_GetResetFlag1(void)
{
    AO_ResetFlag1 reset_flag = { 0U };

    reset_flag.All = TSB_AOREG->RSTFLG1 & (~AO_RESET_FLAG_MASK1);
    TSB_AOREG->RSTFLG1 = 0U;

    return reset_flag;
}


/** @} */
/* End of group AOREG_Exported_Functions */

/** @} */
/* End of group AOREG */

/** @} */
/* End of group TX00_Periph_Driver */

#endif                          /* defined(__TMPM066_AOREG_H) */
