/**
 *******************************************************************************
 * @file	main.c
 * @brief	the application functions of CG IDLE demo for the TOSHIBA
 *			'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/09/18
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */
#include "main.h"

/* for MCU */
void __WFI_wait()
{
    __WFI();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
}

/**
  * @brief  The main function of demo
  * @param  None
  * @retval None
  */
int main(void)
{
    SW_Init();
    LED_Init();

    GPIO_ExtIntSrc();
    INTIFAO_ClearINTReq(INTIFAO_ExtINTSrc);
    NVIC_ClearPendingIRQ(ExtINTSrc_IRQn);

    NVIC_EnableIRQ(ExtINTSrc_IRQn);

    LED_On(LED_EXT);
    while (1U) {

        if (SW_Get(CG_SW) == 0U) {
            LED_On(LED_EXT);

            /* LED indicator is off before enter IDLE */
            LED_Off(LED_SW);

            enter_IDLE();

        } else {
          
            LED_On(LED_SW);
           
            LED_Off(LED_EXT);
        }
    }
}

/**
  * @brief  Enter the IDLE low power mode
  * @param  None
  * @retval None
  */
void enter_IDLE(void)
{
  INTIFAO_SetSTBYReleaseINTSrc(INTIFAO_ExtINTSrc, INTIFAO_INT_ACTIVE_STATE_RISING, ENABLE);
    /* Set standby mode as IDLE */
    CG_SetSTBYMode(CG_STBY_MODE_IDLE);

    __DSB();
    __WFI_wait();

    /* INT release */
      INTIFAO_SetSTBYReleaseINTSrc(INTIFAO_ExtINTSrc, INTIFAO_INT_ACTIVE_STATE_RISING, DISABLE);
}

/**
  * @brief  Set GPIO of External interrupt source
  * @param  None
  * @retval None
  */
void GPIO_ExtIntSrc(void)
{
    GPIO_SetInput(GPIO_ExtINTSrc, Bit_ExtINTSrc);
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1U) {
        __NOP();
    }
}
#endif
