/**
 *******************************************************************************
 * @file    cg.c
 * @brief   The driver functions of CG for the TOSHIBA 'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/09/29
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */
/* Includes ------------------------------------------------------------------*/
#include "cg.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define WDT_DISABLE				((uint32_t)0x00000000)
#define WDT_DISABLE_CODE		((uint32_t)0x000000B1)

#define CG_WUODR_EXT            ((uint16_t)0xC350)
#define CG_WUODR_INT            ((uint16_t)0xC350)
#define CG_WUODR_PLL            ((uint16_t)0xC350)

#define SR_BUSY_FLAG            ((uint32_t)0x00000000)
#define SR_BUSY_MASK            ((uint32_t)0x00000001)

#define CG_OSCCR_EOSCEN_UNUSE	((uint32_t)0xFFFFFFF9)
#define CG_OSCCR_EOSCEN_EHOSC   ((uint32_t)0x00000002)

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Global variables ----------------------------------------------------------*/
/* external variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
Result CG_EnableClkMulCircuit(void);
/* Private functions ---------------------------------------------------------*/

/* for MCU */
void __WFI_wait()
{
    __WFI();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
}

/* Switch over from IHOSC to EHOSC*/
void switchFromIHOSCtoEHOSC(void)
{
	uint32_t regval = TSB_CG->OSCCR;

    CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_EXT_HIGH, CG_WUODR_EXT);
    regval |= CG_OSCCR_EOSCEN_EHOSC;
    TSB_CG->OSCCR = regval;
    /* Start warm-up */
    CG_StartWarmUp();
    /* Wait until EHOSC become stable */
    while (CG_GetWarmUpState() != DONE) {
    }
    /* Set fosc source */
    CG_SetFoscSrc(CG_FOSC_OSC_EXT);
    /* Wait for <OSCSEL> to become "1" */
    while (CG_GetFoscSrc() != CG_FOSC_OSC_EXT) {
    }
    /* Set up pll and wait for pll to warm up, set fc source to fpll */
    CG_EnableClkMulCircuit();
    /* Set fgear = fc */
    CG_SetFgearLevel(CG_DIVIDE_1);
    /* Set T0 = fc . modify this case by case !*/
    CG_SetPhiT0Level(CG_DIVIDE_1);
}

/* CG_NormalToStop */
void CG_NormalToStop(void)
{
    uint32_t regval;
    WorkState st = BUSY;

	TSB_WD->MOD = WDT_DISABLE;
	TSB_WD->CR = WDT_DISABLE_CODE;
	while((TSB_FC->SR & SR_BUSY_MASK) == SR_BUSY_FLAG){
	}
    do {
    	st = CG_GetWarmUpState();
	} while (st != DONE);
    /* Set CG module: Normal ->Stop mode */
    CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_INT_HIGH, CG_WUODR_INT);
    /* Set low power consumption mode stop1 */
    CG_SetSTBYMode(CG_STBY_MODE_STOP1);
	CG_SetFcSrc(CG_FC_SRC_FOSC);
	while(CG_GetFcSrc() == CG_FC_SRC_FPLL){
	}
	CG_SetPLL(DISABLE);
    /* Set fosc source */
    CG_SetFoscSrc(CG_FOSC_OSC_INT);
    /* Wait for <OSCSEL> to become "0" */
    while (CG_GetFoscSrc() == CG_FOSC_OSC_EXT) {
    }
	regval = (TSB_CG->OSCCR & CG_OSCCR_EOSCEN_UNUSE);
	TSB_CG->OSCCR = regval;
	while(TSB_CG->OSCCR != regval){
	}
    /* Enter stop mode */
    __WFI_wait();
}

/* CG_EnableClkMulCircuit */
Result CG_EnableClkMulCircuit(void)
{
    Result retval = ERROR;
    WorkState st = BUSY;

	CG_SetFcSrc(CG_FC_SRC_FOSC);
	while(CG_GetFcSrc() == CG_FC_SRC_FPLL){
	}
    CG_SetPLL(DISABLE);
    CG_SetFPLLValue(CG_12M_MUL_8_FPLL);
    /* Set warm up time */
    CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_EXT_HIGH, CG_WUODR_PLL);
    CG_StartWarmUp();
    do {
		st = CG_GetWarmUpState();
    } while (st != DONE);
    retval = CG_SetPLL(ENABLE);
    if (retval == SUCCESS) {
        /* Set warm up time */
        CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_EXT_HIGH, CG_WUODR_PLL);
        CG_StartWarmUp();
        do {
            st = CG_GetWarmUpState();
        } while (st != DONE);
       CG_SetFcSrc(CG_FC_SRC_FPLL);
    } else {
        /*Do nothing */
    }
    return retval;
}

/*********************************** END OF FILE ******************************/
