/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of CG_ModeSwitch demo for the TOSHIBA
 *          'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/09/29
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************

EHCLKIN : Clock input from the X1 pins
EHOSC : Output clock from the external high-speed oscillator
IHOSC : Output clock from the internal high-speed oscillator.(for SYS)
FOSCHI : Clock specified by CGOSCCR<HOSCON>
fosc : Clock specified by CGOSCCR<OSCSEL>
fpll : Clock multiplied by PLL
fc : Clock specified by CGPLLSEL<PLLSEL> (high-speed clock)
fgear : Clock specified by CGSYSCR<GEAR[2:0]>
fsys : Clock specified by CGSYSCR<GEAR[2:0]>.(system clock)
fperiph : Clock specified by CGSYSCR<FPSEL[2:0]>
phiT0 : Clock specified by CGSYSCR<PRCK[2:0]> (prescaler clock)

 */
/* Includes ------------------------------------------------------------------*/
#include "main.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define NORMAL_MODE             ((uint8_t)0x00)
#define STOP_MODE               ((uint8_t)0x01)
#define TX_MASK					((uint32_t)0x000000A0)
#define TX_END					((uint32_t)0x00000080)
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Global variables ----------------------------------------------------------*/
uint8_t gCurrentMode = NORMAL_MODE;
/* external variables --------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void Mode_Judgement(void);
void System_Init(void);

/* Main function */
int main(void)
{
	uint32_t regval;

    System_Init();

    /* Initialize Variables */
    gCurrentMode = NORMAL_MODE;
    common_uart_disp("NORMAL MODE\r\n");

    while (1) {
        Mode_Judgement();       /* Push SW1 to change Mode */

        switch (gCurrentMode) {
        case NORMAL_MODE:
            LED_On(LED_ALL);
            common_uart_disp("NORMAL MODE\r\n");
            break;
        case STOP_MODE:
            LED_Off(LED_ALL);
            common_uart_disp("STOP MODE\r\n");
    		do {
				regval = UART_RETARGET->MOD2;
				regval &= TX_MASK;
			} while(regval != TX_END);
			UART_Disable(UART_RETARGET);

            /* Switch from normal mode to stop1 mode */
            CG_NormalToStop();

            switchFromIHOSCtoEHOSC();
            System_Init();
            gCurrentMode = NORMAL_MODE;
            break;
        default:
            gCurrentMode = NORMAL_MODE;
            break;
        }
    }

}

/**
  * @brief  Judge whether go to STOP_MODE
  * @param  None.
  * @retval None.
  */
void Mode_Judgement(void)
{
    uint8_t SW1_info = 0U;
    SW1_info = SW_Get(SW1);

    if ((1U == SW1_info) && (gCurrentMode == NORMAL_MODE)) {
        gCurrentMode = STOP_MODE;
    } else {
        /* Do nothing */
    }
}

/**
  * @brief  Initialize system
  * @param  None.
  * @retval None.
  */
void System_Init(void)
{
    /* for M066, Int5 is PF0 = pin30, internal pull up */
    GPIO_SetInput(GPIO_PF, GPIO_BIT_0); 
    GPIO_SetPullUp(GPIO_PF, GPIO_BIT_0, ENABLE); 

    /* Configure GPIO to LED */
    LED_Init();
    SW_Init();

    /* Disable interrupts */
    __disable_irq();

    /* Set external interrupt to wake up system */
    INTIFAO_SetSTBYReleaseINTSrc(INTIFAO_INT_SRC_5,INTIFAO_INT_ACTIVE_STATE_FALLING,ENABLE);
    NVIC_ClearPendingIRQ(INT5_IRQn);
    NVIC_EnableIRQ(INT5_IRQn);
    __enable_irq();

    /* Configure UART */
	UART_SWReset(UART_RETARGET);
    hardware_init(UART_RETARGET);
}


#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

/*********************************** END OF FILE ******************************/
