/**
 *******************************************************************************
 * @file    main.c
 * @brief   The main functions of I2CS slave wake up demo for the
 *          TOSHIBA 'TMPM066' Device Series
 * @version V0.100
 * @date    2015/10/22
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#include "main.h"

I2C_InitTypeDef myI2C;
volatile uint32_t gI2CRCnt;

char gI2CRxData[8] = { 0 };

volatile uint32_t gI2CMode;

/**
  * @brief  The main routine of I2C
  * @param  None
  * @retval None
  */
int main(void)
{
    volatile uint32_t gI2CRxDataLen = I2C_RXDATA_LEN;
    uint32_t gICnt;
    uint32_t regval;

    SW_Init();
    LED_Init();

	UART_SWReset(UART_RETARGET);
    hardware_init(UART_RETARGET);

    /* Initialize IO for I2C */
    I2C1_IO_Configuration();

    /* enable clock supply to I2C1 */
    CG_SetFcPeriphB(CG_FC_PERIPH_I2C1, ENABLE);

    /* Initialize variables for I2C */
    gI2CRCnt = 0U;
    gI2CMode = MODE_I2C_INITIAL;

    while (1) {
        switch (gI2CMode) {
        case MODE_I2C_INITIAL:
            for (gICnt = 0U; gICnt < 8U; gICnt++) {
                gI2CRxData[gICnt] = 0U;
            }
            gI2CMode = MODE_I2C_NORMAL;
            gI2CRCnt = 0U;
            common_uart_disp("S5: STOP MODE");
    		common_uart_disp("\r\n\r\n");
            break;

        case MODE_I2C_NORMAL:
        	LED_On(LED_ALL);
        	if (SW_Get(SW1)) {
				gI2CMode = MODE_I2C_STOP;
			}
            break;

        case MODE_I2C_STOP:
        	common_uart_disp("MASTER I2C START: NORMAL MODE");
    		common_uart_disp("\r\n\r\n");
    		do {
				regval = UART_RETARGET->MOD2;
				regval &= TX_MASK;
			} while(regval != TX_END);
			gI2CMode = MODE_I2C_RCV_PRE;
        	LED_Off(LED_ALL);
        	UART_Disable(UART_RETARGET);

        	I2CS_StopStart();
            break;

        case MODE_I2C_RCV_PRE:
        	LED_On(LED_ALL);
            if (gI2CRCnt > 7U) {
				I2CS_ClockChange();
				UART_SWReset(UART_RETARGET);
    			hardware_init(UART_RETARGET);
				SW_Init();
    			LED_Init();
    			I2C1_IO_Configuration();
    			CG_SetFcPeriphB(CG_FC_PERIPH_I2C1, ENABLE);
        		common_uart_disp("S4: I2C SLAVE RECV");
        		common_uart_disp("\r\n\r\n");
        		gI2CMode = MODE_I2C_RCV;
        	}
            break;

        case MODE_I2C_RCV:
            if (SW_Get(SW0)) {
            	for (gICnt = 1U; gICnt <= gI2CRxDataLen; gICnt++) {
                	gI2CRxData[gICnt - 1] = gI2CRxData[gICnt];
                }
                gI2CRxData[gI2CRxDataLen] = '\0';
                common_uart_disp(gI2CRxData);
                common_uart_disp("\r\n");
                common_uart_disp("MASTER I2C to I2C WAKE UP OK");
                common_uart_disp("\r\n\r\n");
                gI2CMode = MODE_I2C_INITIAL;
                gI2CRCnt = 0U;
            } else {
                /* Do nothing */
            }
            break;

        default:
            gI2CRCnt = 0U;
            gI2CMode = MODE_I2C_INITIAL;
            break;
        }
    }
}

/**
  * @brief  Config the GPIO for I2C1
  * @param  None
  * @retval None
  */
void I2C1_IO_Configuration(void)
{
    GPIO_EnableFuncReg(GPIO_PG, GPIO_FUNC_REG_1, GPIO_BIT_0);
    GPIO_EnableFuncReg(GPIO_PG, GPIO_FUNC_REG_1, GPIO_BIT_1);
    GPIO_SetOutputEnableReg(GPIO_PG, GPIO_BIT_0, ENABLE);
    GPIO_SetOutputEnableReg(GPIO_PG, GPIO_BIT_1, ENABLE);
    GPIO_SetInputEnableReg(GPIO_PG, GPIO_BIT_0, ENABLE);
    GPIO_SetInputEnableReg(GPIO_PG, GPIO_BIT_1, ENABLE);
    GPIO_SetOpenDrain(GPIO_PG, GPIO_BIT_0, ENABLE);
    GPIO_SetOpenDrain(GPIO_PG, GPIO_BIT_1, ENABLE);
}

/**
  * @brief  I2C1 setting
  * @param  None
  * @retval None
  */
void I2C1_Setting(void)
{
    uint8_t tmp = 0U;

	/* Initialize I2C channel 1 */
	myI2C.I2CSelfAddr = SLAVE_ADDR;
	myI2C.I2CDataLen = I2C_DATA_LEN_8;
	myI2C.I2CACKState = ENABLE;
	myI2C.I2CClkDiv = I2C_SCK_CLK_DIV_20;
	myI2C.PrescalerClkDiv = I2C_PRESCALER_DIV_2;

	I2C_SWReset(TSB_I2C1);
	I2C_Init(TSB_I2C1, &myI2C);
	I2C_SetGeneralCall(TSB_I2C1, DISABLE);

	NVIC_EnableIRQ(INTI2CS_IRQn);
	NVIC_EnableIRQ(INTI2C1_IRQn);

	I2C_SetINTI2CReq(TSB_I2C1, ENABLE);
	INTIFAO_SetSTBYReleaseINTSrc(INTIFAO_INT_SRC_I2CS,INTIFAO_INT_ACTIVE_STATE_RISING,ENABLE);
	I2CS_INTRelease(DISABLE);

	I2CS_Reset(DISABLE);
	I2CS_Set1stSlaveAdd(SLAVE_ADDR >> 1);
	I2CS_SetACK(ENABLE);

	tmp = TSB_I2CS->WUPCR1;
	/* General call detection off */
	tmp |= I2CWUPCR_SCGDI_OFF;
	/* Slave receive */
	tmp &= I2CWUPCR_RW_RECEIVE;
	TSB_I2CS->WUPCR1 = tmp; 
}

/**
  * @brief  Interrupt wait instruction
  * @param  None
  * @retval None
  */
void __WFI_wait()
{
    __WFI();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
}

/**
  * @brief  Use the clock gear switching
  * @param  None
  * @retval None
  */
void I2CS_ClockChange(void)
{
	uint32_t regval = TSB_CG->OSCCR;

    CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_EXT_HIGH, CG_WUODR_EXT);
    regval |= CG_OSCCR_EOSCEN_EHOSC;
    TSB_CG->OSCCR = regval;
    /* Start warm-up */
    CG_StartWarmUp();
    /* Wait until EHOSC become stable */
    while (CG_GetWarmUpState() != DONE) {
    }
    /* Set fosc source */
    CG_SetFoscSrc(CG_FOSC_OSC_EXT);
    /* Wait for <OSCSEL> to become "1" */
    while (CG_GetFoscSrc() != CG_FOSC_OSC_EXT) {
    }
    /* Set up pll and wait for pll to warm up, set fc source to fpll */
    I2CS_PLLSetting();
    /* Set fgear = fc */
    CG_SetFgearLevel(CG_DIVIDE_1);
    /* Set T0 = fc . modify this case by case !*/
    CG_SetPhiT0Level(CG_DIVIDE_1);
}

/**
  * @brief  Stop mode start
  * @param  None
  * @retval None
  */
void I2CS_StopStart(void)
{
    uint32_t regval;
    WorkState st = BUSY;

	TSB_WD->MOD = WDT_DISABLE;
	TSB_WD->CR = WDT_DISABLE_CODE;
	while((TSB_FC->SR & SR_BUSY_MASK) == SR_BUSY_FLAG){
	}
    do {
    	st = CG_GetWarmUpState();
	} while (st != DONE);
    /* Set CG module: Normal ->Stop mode */
    CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_INT_HIGH, CG_WUODR_INT);
    /* Set low power consumption mode stop1 */
    CG_SetSTBYMode(CG_STBY_MODE_STOP1);
	CG_SetFcSrc(CG_FC_SRC_FOSC);
	while(CG_GetFcSrc() == CG_FC_SRC_FPLL){
	}
	CG_SetPLL(DISABLE);
    /* Set fosc source */
    CG_SetFoscSrc(CG_FOSC_OSC_INT);
    /* Wait for <OSCSEL> to become "0" */
    while (CG_GetFoscSrc() == CG_FOSC_OSC_EXT) {
    }
	regval = (TSB_CG->OSCCR & CG_OSCCR_EOSCEN_UNUSE);
	TSB_CG->OSCCR = regval;
	while(TSB_CG->OSCCR != regval){
	}
    I2C1_Setting();
    /* Enter stop mode */
    __WFI_wait();
}

/**
  * @brief  PLL configuration changes
  * @param  None
  * @retval None
  */
void I2CS_PLLSetting(void)
{
    Result retval = ERROR;
    WorkState st = BUSY;

	CG_SetFcSrc(CG_FC_SRC_FOSC);
	while(CG_GetFcSrc() == CG_FC_SRC_FPLL){
	}
    CG_SetPLL(DISABLE);
    CG_SetFPLLValue(CG_12M_MUL_8_FPLL);
    /* Set warm up time */
    CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_EXT_HIGH, CG_WUODR_PLL);
    CG_StartWarmUp();
    do {
		st = CG_GetWarmUpState();
    } while (st != DONE);
    retval = CG_SetPLL(ENABLE);
    if (retval == SUCCESS) {
        /* Set warm up time */
        CG_SetWarmUpTime(CG_WARM_UP_SRC_OSC_EXT_HIGH, CG_WUODR_PLL);
        CG_StartWarmUp();
        do {
            st = CG_GetWarmUpState();
        } while (st != DONE);
       CG_SetFcSrc(CG_FC_SRC_FPLL);
    } else {
        /*Do nothing */
    }
}


#ifdef DEBUG
/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
