/**
 *******************************************************************************
 * @file    main.h
 * @brief   The header file for main.c of I2CS slave wake up demo for the
 *          TOSHIBA 'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/10/22
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __MAIN_H
#define __MAIN_H

#include "sw.h"
#include "led.h"
#include "common_uart.h"
#include "tmpm066_gpio.h"
#include "tmpm066_i2c.h"
#include "tmpm066_i2cs.h"
#include "tmpm066_uart.h"
#include "tmpm066_intifao.h"
#include "tmpm066_cg.h"


#define I2C_RXDATA_LEN		    ((uint8_t)0x07)

#define SLAVE_ADDR              ((uint8_t)0xB0)

#define MODE_I2C_INITIAL        ((uint8_t)0x10)
#define MODE_I2C_NORMAL		    ((uint8_t)0x20)
#define MODE_I2C_STOP		    ((uint8_t)0x30)
#define MODE_I2C_RCV_PRE	    ((uint8_t)0x40)
#define MODE_I2C_RCV            ((uint8_t)0x50)

#define I2CWUPCR_SCGDI_OFF      ((uint8_t)0x40)
#define I2CWUPCR_RW_RECEIVE     ((uint8_t)0xF7)

#define CG_WUODR_EXT            ((uint16_t)0xC350)
#define CG_WUODR_INT            ((uint16_t)0xC350)
#define CG_WUODR_PLL            ((uint16_t)0xC350)

#define I2CS_FLAG_ALLCLEAR      ((uint8_t)0xC0)
#define I2CS_MODEEN_SET         ((uint8_t)0x07)

#define WDT_DISABLE				((uint32_t)0x00000000)
#define WDT_DISABLE_CODE		((uint32_t)0x000000B1)

#define SR_BUSY_FLAG            ((uint32_t)0x00000000)
#define SR_BUSY_MASK            ((uint32_t)0x00000001)

#define CG_OSCCR_EOSCEN_UNUSE	((uint32_t)0xFFFFFFF9)
#define CG_OSCCR_EOSCEN_EHOSC   ((uint32_t)0x00000002)

#define TX_MASK					((uint32_t)0x000000A0)
#define TX_END					((uint32_t)0x00000080)

volatile extern uint32_t gI2CRCnt;
extern char gI2CRxData[8];

void I2C1_IO_Configuration(void);
void I2C1_Setting(void);
void I2CS_StopStart(void);
void I2CS_PLLSetting(void);
void I2CS_ClockChange(void);

#endif                          /* __MAIN_H */
