/**
 *******************************************************************************
 * @file    tmpm066_i2cs_int.c
 * @brief   The I2CS slave demo for the
 *          TOSHIBA 'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/10/22
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#include "tmpm066_i2cs_int.h"

/**
  * @brief  Interrupt Service Routine for I2CS
  * @param  None
  * @retval None
  */
void INTI2CS_IRQHandler(void)
{
    TSB_I2C_TypeDef *I2Cy;
    I2C_State I2C1_sr;

	I2Cy = TSB_I2C1;

    I2CS_INTRelease(ENABLE);
    I2CS_INTRelease(DISABLE);
    __disable_irq();
    I2C1_sr = I2C_GetState(I2Cy);

    if (!I2C1_sr.Bit.TRx) { /* Rx Mode */
		I2C_GetReceiveData(I2Cy);
	}
    gI2CRCnt = 0U;

    I2CS_INTRelease(ENABLE);
	TSB_INTIFAO->STOP2INT_038 = I2CS_FLAG_ALLCLEAR;
	TSB_INTIFAO->STOP2INT_038 |= I2CS_MODEEN_SET;
    NVIC_ClearPendingIRQ(INTI2CS_IRQn);
    I2C_ClearINTReq(I2Cy);
    __enable_irq();
    I2CS_Reset(ENABLE);
}

/**
  * @brief  Interrupt Service Routine for I2C1
  * @param  None
  * @retval None
  */
void INTI2C1_IRQHandler(void)
{
    uint32_t tmp = 0U;
    TSB_I2C_TypeDef *I2Cy;
    I2C_State I2C1_sr;

    I2Cy = TSB_I2C1;
    I2C1_sr = I2C_GetState(I2Cy);

    if (!I2C1_sr.Bit.MasterSlave) {     /* Slave mode */
        if (!I2C1_sr.Bit.TRx) { /* Rx Mode */
            if (I2C1_sr.Bit.SlaveAddrMatch) {
                /* First read is dummy read for Slave address recognize */
                tmp = I2C_GetReceiveData(I2Cy);
                gI2CRCnt = 0U;
                tmp = 0U;
                I2C_SetSendData(I2Cy, tmp);
            } else {
                /* Read I2C received data and save to I2C_RxData buffer */
                tmp = I2C_GetReceiveData(I2Cy);
                gI2CRxData[gI2CRCnt] = tmp;
                gI2CRCnt++;
                tmp = 0U;
                I2C_SetSendData(I2Cy, tmp);
            }
        } else {                /* Tx Mode */
            /* Do nothing */
        }
    } else {                    /* Master mode */
        /* Do nothing */
    }
}

