/**
 *******************************************************************************
 * @file    tmpm066_i2c_int.c
 * @brief   The I2C ISR of I2C master demo for the
 *          TOSHIBA 'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/09/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#include "tmpm066_i2c_int.h"



/**
  * @brief  Interrupt Service Routine for I2C
  * @param  None
  * @retval None
  */
void INTI2C0_IRQHandler(void)
{
    TSB_I2C_TypeDef *I2Cx;
    I2C_State I2C_sr;

    I2Cx = TSB_I2C0;
    I2C_sr = I2C_GetState(I2Cx);

    if (I2C_sr.Bit.MasterSlave) {       /* Master mode */
        if (I2C_sr.Bit.TRx) {   /* Tx mode */
            if (I2C_sr.Bit.LastRxBit) { /* LRB=1: the receiver requires no further data. */
                I2C_GenerateStop(I2Cx);
            } else {            /* LRB=0: the receiver requires further data. */
                if (gI2CWCnt <= gI2CTxDataLen) {
                    I2C_SetSendData(I2Cx, gI2CTxData[gI2CWCnt]);        /* Send next data */
                    gI2CWCnt++;
                } else {        /* I2C data send finished. */
                    I2C_GenerateStop(I2Cx);     /* Stop I2C */
                    gI2C_stop_flag = 1U;
                }
            }
        } else {                /* Rx Mode */
            /* Do nothing */
        }
    } else {                    /* Slave mode */
        /* Do nothing */
    }
}
