/**
 *******************************************************************************
 * @file    tmpm066_i2c_int.c
 * @brief   The I2C ISR of I2C slave demo for the
 *          TOSHIBA 'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/09/11
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#include "tmpm066_i2c_int.h"

/**
  * @brief  Interrupt Service Routine for I2C0
  * @param  None
  * @retval None
  */
void INTI2C0_IRQHandler(void)
{
    uint32_t tmp = 0U;
    TSB_I2C_TypeDef *I2Cy;
    I2C_State I2C0_sr;

    I2Cy = TSB_I2C0;
    I2C0_sr = I2C_GetState(I2Cy);

    if (!I2C0_sr.Bit.MasterSlave) {     /* Slave mode */
        if (!I2C0_sr.Bit.TRx) { /* Rx Mode */
            if (I2C0_sr.Bit.SlaveAddrMatch) {
                /* First read is dummy read for Slave address recognize */
                tmp = I2C_GetReceiveData(I2Cy);
                gI2CRCnt = 0U;
                tmp = 0U;
                I2C_SetSendData(I2Cy, tmp);
            } else {
                /* Read I2C received data and save to I2C_RxData buffer */
                tmp = I2C_GetReceiveData(I2Cy);
                gI2CRxData[gI2CRCnt] = tmp;
                gI2CRCnt++;
                tmp = 0U;
                I2C_SetSendData(I2Cy, tmp);
            }
        } else {                /* Tx Mode */
            /* Do nothing */
        }
    } else {                    /* Master mode */
        /* Do nothing */
    }
}
