/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMR16A_TIMER demo for the TOSHIBA
 *          'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/10/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "tmpm066_cg.h"

/**
  * @brief  The main function of TMR16A_TIMER demo
  * @param  None
  * @retval None
  */
int main(void)
{

    LED_Init();                 /* LED initialize */
    LED_On(LED_ALL);            /* Turn on LED_ALL */
    
    /* enable clock supply to TMR16A */
    CG_SetFcPeriphA(CG_FC_PERIPH_TMR16A, ENABLE);
    
    TMR16A_SetRunState(TSB_T16A0, TMR16A_STOP); /* Counter stops */
    TMR16A_SetSrcClk(TSB_T16A0, TMR16A_SYSCK);  /* Set source clock to system clock */
    TMR16A_ChangeCycle(TSB_T16A0, TMR16A_1MS);  /* Set counter value to 1ms */

    NVIC_EnableIRQ(INT16A0_IRQn);
    TMR16A_SetRunState(TSB_T16A0, TMR16A_RUN);

    while (1) {
        /* Do nothing */
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
