/** 
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of TMRD interval timer demo for the TOSHIBA
 *          'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/10/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#include "tmpm066_tmrd.h"
#include "tmpm066_cg.h"
#include "led.h"

/* fosc = 12MHz(external high-speed oscillator)
 * fpll = 8 * fosc = 96MHz(in this demo, PLL multiplying value is set to 8 multiplying)
 * ftmrd = fpll = 96MHz(in this demo, ftmrd = fpll)
 * So the value of TIME_500US is 500us*ftmrd = 48000 = 0xBB80U
 */
#define TIME_500US    ((uint16_t)0xBB80U)

int main(void)
{
    LED_Init();

    /* TMRD CG setting */
    CG_SetFcOptional(CG_FPLL_PERIPH_TMRD,ENABLE);
    CG_SetFcPeriphA(CG_FC_PERIPH_TMRD,ENABLE);

    /* TMRD mode setting */
    TMRD_SetMode(TMRD_MODE_BOTH_TMR);

    /* TMRD IDLE mode */
    TMRD_SetRunStateInIdle(TMRD_UNIT_CH_0, TMRD_RUN);

    /* TMRD enable clock signal */
    TMRD_Enable(TMRD_UNIT_CH_0);

    /* Set the TMRD prescaler */
    TMRD_SetClkDivision(TMRD_UNIT_CH_0, TMRD_CLK_DIV_1);

    /* Set the upcounter clear mode */
    TMRD_SetUpCntCtrl(TMRD_UNIT_CH_0, TMRD_AUTO_CLEAR);

    /* Direct update the compare register */
    TMRD_SetCMPRegWritePath(TMRD_UNIT_CH_0, TMRD_CMP_WRITE_DIRECT);

    /* Set the value to timer register */
    TMRD_ChangeTiming(TMRD_TIMING_TD0_CYCLE, TIME_500US);      /* 500us */

    /* Indirct update the compare register */
    TMRD_SetCMPRegWritePath(TMRD_UNIT_CH_0, TMRD_CMP_WRITE_INDIRECT);

    /* Enable TMRD intterrupt */
    TMRD_SetCMP0INTSrc(TMRD_UNIT_CH_0, TMRD_INT_MATCH_CYCLE);

    NVIC_EnableIRQ(INTTMRD_IRQn);

    /* Start to run TMRD */
    TMRD_SetRunState(TMRD_UNIT_CH_0, TMRD_RUN);

    while (1) {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
