/**
 *******************************************************************************
 * @file    usbd_cdc.h
 * @brief   CDC(ACM) Function Header for TOSHIBA Cortex M0/M3/M4 Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#ifndef _USBD_CDC_H_
#define _USBD_CDC_H_

#include "usbd_hw.h"
#include "usbd_trans.h"

/* Class request code */
#define USBD_CDC_SEND_ENCAPSULATED_COMMAND  (0x00U)
#define USBD_CDC_GET_ENCAPSULATED_RESPONSE  (0x01U)
#define USBD_CDC_SET_COMM_FEATURE           (0x02U)
#define USBD_CDC_GET_COMM_FEATURE           (0x03U)
#define USBD_CDC_CLEAR_COMM_FEATURE         (0x04U)
#define USBD_CDC_SET_LINE_CODING            (0x20U)
#define USBD_CDC_GET_LINE_CODING            (0x21U)
#define USBD_CDC_SET_CONTROL_LINE_STATE     (0x22U)
#define USBD_CDC_SEND_BREAK                 (0x23U)

/* Interface number */
#define USBD_CDC_MANAGEMENT_IF              (0x00U)
#define USBD_CDC_NOTIFICATION_IF            (0x00U)

/* Abstract Model Notification code */
#define USBD_CDC_NETWORK_CONNECTION         (0x00U)
#define USBD_CDC_RESPONSE_AVAILABLE         (0x01U)
#define USBD_CDC_SERIAL_STATE               (0x20U)

/* Abstract Model Feature Selector code */
#define USBD_CDC_ABSTRACT_STATE             (0x01U)

/* Abstract Model Request send data size */
#define USBD_CDC_FEATURE_STATUS_SIZE        (0x02U)
#define USBD_CDC_LINE_CODING_SIZE           (0x07U)

/* The bmCapabilities bitmap value of Abstract Control Management Functional Descriptor */
#define USBD_CDC_BM_CAPA_NETWORK            (0x08U)
#define USBD_CDC_BM_CAPA_BREAK              (0x04U)
#define USBD_CDC_BM_CAPA_LINE_SERIAL        (0x02U)
#define USBD_CDC_BM_CAPA_FEATURE            (0x01U)

/* The bmCapabilities bitmap value of Call Management Functional Descriptor */
#define USBD_CDC_BM_CAPA_DATA_CLASS         (0x02U)
#define USBD_CDC_BM_CAPA_CALL_MANAGEMENT    (0x01U)

/* Request Data Buffer Size */
#define USBD_CDC_REQ_DATA_BUF_SIZE          (32U)

/* Structure of Notification Request */
typedef struct {
    uint8_t         bmRequestType;      /* Request Type */
    uint8_t         bNotification;      /* Notification Code */
    uint16_t        wValue;             /* Value */
    uint16_t        wIndex;             /* Index */
    uint16_t        wLength;            /* Data Phase Length */
} Notification_t;

/* Structure of The data of a Notification Request is included */
typedef struct {
    Notification_t  tNotice;            /* Notification Request structure */
    uint16_t        usState;            /* State */
} NotificationSerialState_t;

/* Typedef for CDC Callback Functions */
typedef void (*CDC_CB_ConnStat)(bool);
typedef void (*CDC_CB_SendEncapsulatedCmd)(uint32_t, uint8_t*);
typedef void (*CDC_CB_Get)(uint16_t);
typedef void (*CDC_CB_Set)(uint32_t, uint8_t*);
typedef void (*CDC_CB_ClearCommFeature)(void);
typedef void (*CDC_CB_SetControlLineState)(uint16_t);
typedef void (*CDC_CB_SendBreak)(uint16_t);
typedef void (*CDC_CB_Notification)(void);
typedef void (*CDC_CB_TrnsData)(uint32_t, uint8_t*, uint16_t);

/* Callback Information */
typedef struct {
    CDC_CB_ConnStat                 pfnConnStat;
    CDC_CB_SendEncapsulatedCmd      pfnSendEncapsulatedCmd;
    CDC_CB_Get                      pfnGetEncapsulatedRes;
    CDC_CB_Set                      pfnSetCommFeature;
    CDC_CB_Get                      pfnGetCommFeature;
    CDC_CB_ClearCommFeature         pfnClearCommFeature;
    CDC_CB_Set                      pfnSetLineCoding;
    CDC_CB_Get                      pfnGetLineCoding;
    CDC_CB_SetControlLineState      pfnSetControlLineState;
    CDC_CB_SendBreak                pfnSendBreak;
    CDC_CB_Notification             pfnNetworkConnection;
    CDC_CB_Notification             pfnResponseAvailable;
    CDC_CB_Notification             pfnSerialState;
    CDC_CB_TrnsData                 pfnSendData;
    CDC_CB_TrnsData                 pfnReciveData;
} CDC_CB_t;

/* CDC Initialize */
extern void usbd_cdc_init(CDC_CB_t*);

/* CDC Request Handler */
extern bool usbd_interrupt_CDC_req(uint32_t);

/* Other Prototypes */
extern bool USBD_CDC_SendData(uint32_t, uint8_t*);
extern bool USBD_CDC_RecvData(uint32_t, uint8_t*);
extern bool USBD_CDC_Notification_NetworkConnection(uint16_t);
extern bool USBD_CDC_Notification_ResponseAvailable(void);
extern bool USBD_CDC_Notification_SerialState(uint16_t);
extern bool USBD_CDC_Send_GetEncapsulatedResponse(uint32_t, uint8_t*);
extern bool USBD_CDC_Send_GetCommFeature(uint32_t, uint8_t*);
extern bool USBD_CDC_Send_GetLineCoding(uint32_t, uint8_t*);
extern void USBD_CDC_Connect(void);
extern void USBD_CDC_DisConnect(void);

#endif /* _USBD_CDC_H_ */
