/**
 *******************************************************************************
 * @file    usbd_descriptor_cdc.h
 * @brief   CDC(ACM) Descriptor Defines for TOSHIBA Cortex M0/M3/M4  Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#ifndef _USBD_DESCRIPTOR_CDC_H_
#define _USBD_DESCRIPTOR_CDC_H_

#include "usbd_descriptor.h"

/*
 *  bLength for CDC
 */
#define CbLength_HeaderF                (0x05U)
#define CbLength_ACMF                   (0x04U)
#define CbLength_UnionF                 (0x05U)
#define CbLength_CMF                    (0x05U)
/*
 *  bDescripterType for CDC
 */
#define CbDescripterType_CSINTERFACE    (0x24U)
#define CbDescripterType_HeaderF        CbDescripterType_CSINTERFACE
#define CbDescripterType_ACMF           CbDescripterType_CSINTERFACE
#define CbDescripterType_UnionF         CbDescripterType_CSINTERFACE
#define CbDescripterType_CMF            CbDescripterType_CSINTERFACE
/*
 *  bDescriptorSubtype for CDC
 */
#define CbDescripterSubtype_HeaderF     (0x00U)
#define CbDescripterSubtype_ACMF        (0x02U)
#define CbDescripterSubtype_UnionF      (0x06U)
#define CbDescripterSubtype_CMF         (0x01U)

/*
 *  for Device Descriptor
 */
#define CbNumConfigrations              (0x01U)     /* Number of configurations */
#define CbConfigurationValue1           (0x01U)     /* Index of configuration   */

/*
 *  for Configuration Descriptor
 */
#define CbNumInterfacesConf1            (0x02U)     /* Number of configurations1 interfaces    */
#define CbInterfaceNumber1_0            (0x00U)     /* Index of configuration1 interface index */
#define CbAlternateSetting1_0           (0x00U)

#define CbInterfaceNumber_Init          CbInterfaceNumber1_0
#define CbAlternateSetting_Init         CbAlternateSetting1_0

#define CwTotalLengthConf1              (CbLength_Configuration + CbLength_Interface + CbLength_HeaderF + CbLength_ACMF + CbLength_UnionF + CbLength_CMF + CbLength_Endpoint + CbLength_Interface + CbLength_HeaderF + CbLength_Endpoint + CbLength_Endpoint)

/*
 *  for Endpoint Descriptor
 */
#define CwMaxPacketSize_FS              (0x0040U)
#define CwMaxPacketSize_HS              (0x0200U)

#define CwMaxPacketSize_EP0             (0x0040U)
#define CwMaxPacketSize_EP1_INIT        CwMaxPacketSize_FS
#define CwMaxPacketSize_EP2_INIT        CwMaxPacketSize_FS
#define CwMaxPacketSize_EP3_INIT        CwMaxPacketSize_FS

#define CbNumEndPoints1_0               (0x01U)
#define CbNumEndPoints1_1               (0x02U)

/*
 *  for String Descriptor
 */
#define CStringLanguageSupport_SIZE     (0x02U)
#define CStringLaguageID_0              (0x0409U)
#define CStringManufacturer_SIZE        (0x10U)
#define CStringProduct_SIZE             (0x10U)
#define CStringSerialNumber_SIZE        (0x10U)
#define CStringMicroController_SIZE     (0x1EU)

#define CStringDataIndex                (0x02U)     /* Micro controller information index at string descriptor */

#define CbNumStringDescriptor           (0x05U)
#define CStringSize_LanguageSupport     (0x02U + CStringLanguageSupport_SIZE)
#define CStringSize_Manufacturer        (0x02U + CStringManufacturer_SIZE)
#define CStringSize_Product             (0x02U + CStringProduct_SIZE)
#define CStringSize_SerialNumber        (0x02U + CStringSerialNumber_SIZE)
#define CStringSize_MicroController     (0x02U + CStringMicroController_SIZE)

/* struct for interface */
typedef struct {
    const InterfaceDescriptor_t         *p_interface;
    const EndpointDescriptor_t          **pp_endpoint;
} StructInterfaceDesc_t;

/* struct for configuration */
typedef struct {
    const ConfigDescriptor_t            *p_config;
    const StructInterfaceDesc_t         *p_struct_interface[CbNumInterfacesConf1];
    const uint8_t                       *p_sring;
} StructConfigDesc_t;

/* struct for Device Descriptor */
typedef struct {
    const DeviceDescriptor_t            *p_device;
    const StructConfigDesc_t            *p_struct_config[CbNumConfigrations];
} UserDescriptor_t;

/* struct for String Descriptor (LANGID) */
typedef struct {
    uint8_t bLength;                                /* Size of this descriptor */
    uint8_t bDescripterType;                        /* Descriptor type         */
    uint16_t wLang;                                 /* LanguageID code         */
} StringDescriptorLanguageSupport_t;

/* CDC/ACM Descriptor(s) */
/* struct for Header Functional Descriptor */
typedef struct {
    uint8_t bLength;                                /* Size of this descriptor                       */
    uint8_t bDescripterType;                        /* Descriptor type                               */
    uint8_t bDescriptorSubtype;                     /* Descriptor subtype                            */
    uint16_t bcdCDC;                                /* CDC Specification release number              */
} HeaderFunctionalDescriptor_t;

/* struct for Abstract Control Management Functional Descriptor */
typedef struct {
    uint8_t bLength;                                /* Size of this descriptor                       */
    uint8_t bDescriptorType;                        /* Descriptor type                               */
    uint8_t bDescriptorSubtype;                     /* Descriptor subtype                            */
    uint8_t bmCapabilities;                         /* Capabilities that this configuration supports */
} AbstractControlManagementFunctionalDescriptor_t;

/* struct for Union Functional Descriptor */
typedef struct {
    uint8_t bLength;                                /* Size of this descriptor                       */
    uint8_t bDescriptorType;                        /* Descriptor type                               */
    uint8_t bDescriptorSubtype;                     /* Descriptor subtype                            */
    uint8_t bMasterInterface;                       /* Interface number of master                    */
    uint8_t bSlaveInterface;                        /* Interface number of first slave               */
} UnionFunctionalDescriptor_t;

/* struct for Call Management Functional Descriptor */
typedef struct {
    uint8_t bLength;                                /* Size of this descriptor                       */
    uint8_t bDescriptorType;                        /* Descriptor type                               */
    uint8_t bDescriptorSubtype;                     /* Descriptor subtype                            */
    uint8_t bmCapabilities;                         /* Capabilities that this configuration supports */
    uint8_t bDataInterface;                         /* Interface number of Data Class interface      */
} CallManagementFunctionalDescriptor_t;

extern const DeviceDescriptor_t                              gDeviceDescriptor;
extern const ConfigDescriptor_t                              gConfigDescriptor1;
extern const InterfaceDescriptor_t                           gInterfaceDescriptor1_0;
extern const HeaderFunctionalDescriptor_t                    gHeaderFunctionalDescriptor1_0;
extern const AbstractControlManagementFunctionalDescriptor_t gAbstractControlManagementFunctionalDescriptor1_0;
extern const UnionFunctionalDescriptor_t                     gUnionFunctionalDescriptor1_0;
extern const CallManagementFunctionalDescriptor_t            gCallManagementFunctionalDescriptor1_0;
extern const EndpointDescriptor_t                            gEndpointDescriptor1_0_3;
extern const InterfaceDescriptor_t                           gInterfaceDescriptor1_1;
extern const HeaderFunctionalDescriptor_t                    gHeaderFunctionalDescriptor1_1;
extern const EndpointDescriptor_t                            gEndpointDescriptor1_1_1;
extern const EndpointDescriptor_t                            gEndpointDescriptor1_1_2;
extern const DeviceQualifierDescriptor_t                     gDeviceQualifierDescriptor;

extern const EndpointDescriptor_t                            *gEndpointDescriptor1_0[CbNumEndPoints1_0];
extern const StructInterfaceDesc_t                           gStructInterfaceDesc1_0;
extern const EndpointDescriptor_t                            *gEndpointDescriptor1_1[CbNumEndPoints1_1];
extern const StructInterfaceDesc_t                           gStructInterfaceDesc1_1;
extern const StructConfigDesc_t                              gStructConfigDesc[ CbNumConfigrations ];
extern const UserDescriptor_t                                gUserDescriptor;

extern const StringDescriptorLanguageSupport_t               gStringLanguageSupported;
extern const uint8_t                                         gStringDescManu[CStringSize_Manufacturer];
extern const uint8_t                                         gStringDescProd[CStringSize_Product];
extern const uint8_t                                         gStringDescSN[CStringSize_SerialNumber];
extern const uint8_t                                         gStringDescMicro[CStringSize_MicroController];
extern const uint8_t                                         *gStringDescriptor[CbNumStringDescriptor];

#endif  /* _USBD_DESCRIPTOR_CDC_H_ */
