/**
 *******************************************************************************
 * @file    usbd_descriptor_cdc.c
 * @brief   CDC(ACM) Descriptor Code for TOSHIBA Cortex M0/M3/M4 Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#include "usbd_hw.h"
#include "usbd_var.h"
#include "usbd_device_request.h"
#include "usbd_typedefs.h"
#include "usbd_descriptor.h"
#include "usbd_descriptor_cdc.h"

/* xxxxxA_B_C means A:Config B:Interface C:Endpoint */

/**
  * @brief Device Descriptor
  */
const DeviceDescriptor_t gDeviceDescriptor = {
    CbLength_Device,                /* bLength                      */
    CbDescripterType_Device,        /* bDescriptorType              */
    0x0200U,                        /* bcdUSB                       */
    0x002,                          /* bDeviceClass                 */
    0x00U,                          /* bDeviceSubClass              */
    0x00U,                          /* bDeviceProtocol              */
    0x40U,                          /* bMaxPacketSize0              */
    0x0930U,                        /* idVendor                     */
    0x6505U,                        /* idProduct                    */
    0x0001U,                        /* bcdDevice(Low)               */
    0x01U,                          /* iManufacturer                */
    0x02U,                          /* iProduct                     */
    0x03U,                          /* iSerialNumber                */
    CbNumConfigrations              /* bNumConfigrations            */
};

/**
  * @brief Configuration Descriptor (Config:1)
  */
const ConfigDescriptor_t gConfigDescriptor1 = {
    CbLength_Configuration,         /* bLength                      */
    CbDescripterType_Configuration, /* bDescriptorType              */
    CwTotalLengthConf1,             /* wTotalLength                 */
    0x02U,                          /* bNumInterfaces               */
    CbConfigurationValue1,          /* bConfigurationValue          */
    0x00U,                          /* iConfiguration               */
    0xC0U,                          /* bmAttributes                 */
    0x31U                           /* bMaxPower                    */
};

/**
  * @brief Interface Descriptor (Config:1, Interface:0)
  */
const InterfaceDescriptor_t gInterfaceDescriptor1_0 = {
    CbLength_Interface,             /* bLength                      */
    CbDescripterType_Interface,     /* bDescriptorType              */
    0x00U,                          /* bInterfaceNumber             */
    0x00U,                          /* bAlternateSetting            */
    0x01U,                          /* bNumEndpoints                */
    0x02U,                          /* bInterfaceClass              */
    0x02U,                          /* bInterfaceSubClass           */
    0x00U,                          /* bInterfaceProtocol           */
    0x00U                           /* iInterface                   */
};

/**
  * @brief Header Functional Descriptor (Config:1, Interface:0)
  */
const HeaderFunctionalDescriptor_t gHeaderFunctionalDescriptor1_0 = {
    CbLength_HeaderF,               /* bLength                      */
    CbDescripterType_HeaderF,       /* bDescriptorType              */
    CbDescripterSubtype_HeaderF,    /* bDescriptorSubtype           */
    0x1001U                         /* bcdCDC                       */
};

/**
  * @brief Abstract Control Management Functional Descriptor (Config:1, Interface:0)
  */
const AbstractControlManagementFunctionalDescriptor_t gAbstractControlManagementFunctionalDescriptor1_0 = {
    CbLength_ACMF,                  /* bLength                      */
    CbDescripterType_ACMF,          /* bDescriptorType              */
    CbDescripterSubtype_ACMF,       /* bDescriptorSubtype           */
    0x0FU                           /* bmCapabilities               */
};

/**
  * @brief Union Functional Descriptor (Config:1, Interface:0)
  */
const UnionFunctionalDescriptor_t gUnionFunctionalDescriptor1_0 = {
    CbLength_UnionF,                /* bLength                      */
    CbDescripterType_UnionF,        /* bDescriptorType              */
    CbDescripterSubtype_UnionF,     /* bDescriptorSubtype           */
    0x00U,                          /* bMasterInterface             */
    0x01U                           /* bSlaveInterface              */
};

/**
  * @brief Call Management Functional Descriptor (Config:1, Interface:0)
  */
const CallManagementFunctionalDescriptor_t gCallManagementFunctionalDescriptor1_0 = {
    CbLength_CMF,                   /* bLength                      */
    CbDescripterType_CMF,           /* bDescriptorType              */
    CbDescripterSubtype_CMF,        /* bDescriptorSubtype           */
    0x03U,                          /* bmCapabilities               */
    0x01U                           /* bDataInterface               */
};

/**
  * @brief Endpoint Descriptor (Config:1, Interface:0, Endpoint:3)
  */
const EndpointDescriptor_t gEndpointDescriptor1_0_3 = {
    CbLength_Endpoint,              /* bLength                      */
    CbDescripterType_Endpoint,      /* bDescriptorType              */
    0x83U,                          /* bEndPointAddress             */
    0x03U,                          /* bmAttributes                 */
    CwMaxPacketSize_EP3_INIT,       /* wMaxPacketSize               */
    0x20U                           /* bInterval                    */
};

/**
  * @brief Interface Descriptor (Config:1, Interface:1)
  */
const InterfaceDescriptor_t gInterfaceDescriptor1_1 = {
    CbLength_Interface,             /* bLength                      */
    CbDescripterType_Interface,     /* bDescriptorType              */
    0x01U,                          /* bInterfaceNumber             */
    0x00U,                          /* bAlternateSetting            */
    0x02U,                          /* bNumEndpoints                */
    0x0AU,                          /* bInterfaceClass              */
    0x00U,                          /* bInterfaceSubClass           */
    0x00U,                          /* bInterfaceProtocol           */
    0x00U                           /* iInterface                   */
};

/**
  * @brief Header Functional Descriptor (Config:1, Interface:1)
  */
const HeaderFunctionalDescriptor_t gHeaderFunctionalDescriptor1_1 = {
    CbLength_HeaderF,               /* bLength                      */
    CbDescripterType_HeaderF,       /* bDescriptorType              */
    CbDescripterSubtype_HeaderF,    /* bDescriptorSubtype           */
    0x1001U                         /* bcdCDC                       */
};

/**
  * @brief Endpoint Descriptor (Config:1, Interface:1, Endpoint:1)
  */
const EndpointDescriptor_t gEndpointDescriptor1_1_1 = {
    CbLength_Endpoint,              /* bLength                      */
    CbDescripterType_Endpoint,      /* bDescriptorType              */
    0x81U,                          /* bEndPointAddress             */
    0x02U,                          /* bmAttributes                 */
    CwMaxPacketSize_EP1_INIT,       /* wMaxPacketSize               */
    0x0AU                           /* bInterval                    */
};

/**
  * @brief Endpoint Descriptor (Config:1, Interface:1, Endpoint:2)
  */
const EndpointDescriptor_t gEndpointDescriptor1_1_2 = {
    CbLength_Endpoint,              /* bLength                      */
    CbDescripterType_Endpoint,      /* bDescriptorType              */
    0x02U,                          /* bEndPointAddress             */
    0x02U,                          /* bmAttributes                 */
    CwMaxPacketSize_EP2_INIT,       /* wMaxPacketSize               */
    0x0AU                           /* bInterval                    */
};

/**
  * @brief Device Qualifier Descriptor
  */
const DeviceQualifierDescriptor_t gDeviceQualifierDescriptor = {
    CbLength_DeviceQualifer,        /* bLength(10byte)              */
    CbDescripterType_DeviceQualifer,/* bDescriptorType              */
    0x0200U,                        /* bcdUSB                       */
    0x00U,                          /* bDeviceClass                 */
    0x00U,                          /* bDeviceSubClass              */
    0x00U,                          /* bDeviceProtocol              */
    0x40U,                          /* bMaxPacketSize0(64byte)      */
    CbNumConfigrations,             /* bNumConfiguration            */
    0x00U                           /* Reserve                      */
};

/**
  * @brief Endpoint (Interface:0)
  */
const EndpointDescriptor_t *gEndpointDescriptor1_0[CbNumEndPoints1_0] = {
    &gEndpointDescriptor1_0_3,      /* Endpoint:3               */
};

/**
  * @brief Interface:0 (Config:1)
  */
const StructInterfaceDesc_t gStructInterfaceDesc1_0 = {
    &gInterfaceDescriptor1_0,       /* Interface:0              */
    gEndpointDescriptor1_0          /* Endpoint                 */
};

/**
  * @brief Endpoint (Interface:1)
  */
const EndpointDescriptor_t *gEndpointDescriptor1_1[CbNumEndPoints1_1] = {
    &gEndpointDescriptor1_1_1,      /* Endpoint:1               */
    &gEndpointDescriptor1_1_2       /* Endpoint:2               */
};

/**
  * @brief Interface:1 (Config:1)
  */
const StructInterfaceDesc_t gStructInterfaceDesc1_1 = {
    &gInterfaceDescriptor1_1,       /* Interface:1              */
    gEndpointDescriptor1_1          /* Endpoint                 */
};

/**
  * @brief Configuration:1
  */
const StructConfigDesc_t gStructConfigDesc[ CbNumConfigrations ] = {
    &gConfigDescriptor1,            /* Configuration:1          */
    &gStructInterfaceDesc1_0,       /* Interface:0              */
    &gStructInterfaceDesc1_1,       /* Interface:1              */
    gStringDescMicro                /* String(Micro controller) */
};

/**
  * @brief Device
  */
const UserDescriptor_t gUserDescriptor = {
    &gDeviceDescriptor,             /* Device                   */
    gStructConfigDesc               /* Configuration:1          */
};

/**
  * @brief String Descriptor (LANGID)
  */
const StringDescriptorLanguageSupport_t gStringLanguageSupported = {
    CStringSize_LanguageSupport,    /* Size of Descriptor(byte) */
    CbDescripterType_String,        /* Descriptor Type          */
    CStringLaguageID_0
};

/**
  * @brief String Descriptor (Manufacturer)
  */
const uint8_t gStringDescManu[CStringSize_Manufacturer] = {
    CStringSize_Manufacturer,       /* Size of Descriptor(byte) */
    CbDescripterType_String,        /* Descriptor Type          */
    'T', 0x00U,
    'O', 0x00U,
    'S', 0x00U,
    'H', 0x00U,
    'I', 0x00U,
    'B', 0x00U,
    'A', 0x00U,
    ' ', 0x00U
};

/**
  * @brief String Descriptor (Product)
  */
const uint8_t gStringDescProd[CStringSize_Product] = {
    CStringSize_Product,            /* Size of Descriptor(byte) */
    CbDescripterType_String,        /* Descriptor Type          */
    'T', 0x00U,
    'S', 0x00U,
    'B', 0x00U,
    '-', 0x00U,
    'M', 0x00U,
    'C', 0x00U,
    'U', 0x00U,
    ' ', 0x00U
};

/**
  * @brief String Descriptor (Serial number)
  */
const uint8_t gStringDescSN[CStringSize_SerialNumber] = {
    CStringSize_SerialNumber,       /* Size of Descriptor(byte) */
    CbDescripterType_String,        /* Descriptor Type          */
    '0', 0x00U,
    '1', 0x00U,
    '2', 0x00U,
    '3', 0x00U,
    '4', 0x00U,
    '5', 0x00U,
    '6', 0x00U,
    '7', 0x00U
};

/**
  * @brief String Descriptor (Micro controller)
  * @note If support iConfiguration or iInterface, use this data.
  */
const uint8_t gStringDescMicro[CStringSize_MicroController] = {
    CStringSize_MicroController,    /* Size of Descriptor(byte) */
    CbDescripterType_String,        /* Descriptor Type          */
    'T', 0x00U,
    'S', 0x00U,
    'B', 0x00U,
    '-', 0x00U,
    'C', 0x00U,
    'o', 0x00U,
    'r', 0x00U,
    't', 0x00U,
    'e', 0x00U,
    'x', 0x00U,
    '-', 0x00U,
    '-', 0x00U,
    'U', 0x00U,
    'S', 0x00U,
    'B', 0x00U
};

/**
  * @brief String Descriptor(s)
  */
const uint8_t *gStringDescriptor[CbNumStringDescriptor] = {
    (const uint8_t *) &gStringLanguageSupported,    /* LANGID           */
    gStringDescManu,                                /* Manufacturer     */
    gStringDescProd,                                /* Product          */
    gStringDescSN,                                  /* Serial number    */
    gStringDescMicro                                /* Micro controller */
};

/* EOC */
