/**
 *******************************************************************************
 * @file    usbd_descriptor_hid.h
 * @brief   HID Descriptor Defines for TOSHIBA Cortex M0/M3/M4 Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#ifndef _USBD_DESCRIPTOR_HID_H_
#define _USBD_DESCRIPTOR_HID_H_

#include "usbd_descriptor.h"

/*
 *  bLength for HID
 */
#define CbLength_HIDDescriptor          (0x09U)
#define CbLength_HIDReportDescriptor    (0x34U)
/*
 *  bDescripterType for HID
 */
#define CbDescripterType_HID            (0x21U)
#define CbDescripterType_HIDReport      (0x22U)

/*
 *  for Device Descriptor
 */
#define CbNumConfigrations              (0x01U)     /* Number of configurations */
#define CbConfigurationValue1           (0x01U)     /* Index of configuration   */

/*
 *  for Configuration Descriptor
 */
#define CbNumInterfacesConf1            (0x01U)     /* Number of configuration1 interfaces     */
#define CbInterfaceNumber1_0            (0x00U)     /* Index of configuration1 interface index */
#define CbAlternateSetting1_0           (0x00U)

#define CbInterfaceNumber_Init          CbInterfaceNumber1_0
#define CbAlternateSetting_Init         CbAlternateSetting1_0

#define CwTotalLengthConf1              (CbLength_Configuration + CbLength_Interface + CbLength_HIDDescriptor + CbLength_Endpoint)

/*
 *  for Endpoint Descriptor
 */
#define CwMaxPacketSize_FS              (0x0040U)
#define CwMaxPacketSize_HS              (0x0200U)

#define CwMaxPacketSize_EP0             (0x0040U)
#define CwMaxPacketSize_EP1_INIT        CwMaxPacketSize_FS
#define CwMaxPacketSize_EP2_INIT        CwMaxPacketSize_FS
#define CwMaxPacketSize_EP3_INIT        CwMaxPacketSize_FS

#define CbNumEndPoints1_0               (0x01U)

/*
 *  for String Descriptor
 */
#define CStringLanguageSupport_SIZE     (0x02U)
#define CStringLaguageID_0              (0x0409U)
#define CStringManufacturer_SIZE        (0x10U)
#define CStringProduct_SIZE             (0x10U)
#define CStringSerialNumber_SIZE        (0x10U)
#define CStringMicroController_SIZE     (0x1EU)     /* used in gStringDescMicro[] in usbd_descriptor_hid.c */

#define CStringDataIndex                (0x02U)     /* Micro controller information index at string descriptor */

#define CbNumStringDescriptor           (0x05U)
#define CStringSize_LanguageSupport     (0x02U + CStringLanguageSupport_SIZE)
#define CStringSize_Manufacturer        (0x02U + CStringManufacturer_SIZE)
#define CStringSize_Product             (0x02U + CStringProduct_SIZE)
#define CStringSize_SerialNumber        (0x02U + CStringSerialNumber_SIZE)
#define CStringSize_MicroController     (0x02U + CStringMicroController_SIZE)

/* struct for interface */
typedef struct {
    const InterfaceDescriptor_t         *p_interface;
    const EndpointDescriptor_t          **pp_endpoint;
} StructInterfaceDesc_t;

/* struct for configuration */
typedef struct {
    const ConfigDescriptor_t            *p_config;
    const StructInterfaceDesc_t         *p_struct_interface[CbNumInterfacesConf1];
    const uint8_t                       *p_sring;
} StructConfigDesc_t;

/* struct for device descriptor */
typedef struct {
    const DeviceDescriptor_t            *p_device;
    const StructConfigDesc_t            *p_struct_config[CbNumConfigrations];
} UserDescriptor_t;

/* struct for string descriptor (LANGID) */
typedef struct {
    uint8_t bLength;                                /* Size of this descriptor */
    uint8_t bDescripterType;                        /* Descriptor type         */
    uint16_t wLang;                                 /* LanguageID code         */
} StringDescriptorLanguageSupport_t;

extern const DeviceDescriptor_t                gDeviceDescriptor;
extern const ConfigDescriptor_t                gConfigDescriptor1;
extern const InterfaceDescriptor_t             gInterfaceDescriptor1_0;
extern const EndpointDescriptor_t              gEndpointDescriptor1_0_3;
extern const DeviceQualifierDescriptor_t       gDeviceQualifierDescriptor;
extern const uint8_t                           gHIDDescriptor[CbLength_HIDDescriptor];
extern const uint8_t                           gHIDReportDescriptor[CbLength_HIDReportDescriptor];

extern const EndpointDescriptor_t              *gEndpointDescriptor1_0[CbNumEndPoints1_0];
extern const StructInterfaceDesc_t             gStructInterfaceDesc1_0;
extern const StructConfigDesc_t                gStructConfigDesc[CbNumConfigrations];
extern const UserDescriptor_t                  gUserDescriptor;

extern const StringDescriptorLanguageSupport_t gStringLanguageSupported;
extern const uint8_t                           gStringDescManu[CStringSize_Manufacturer];
extern const uint8_t                           gStringDescProd[CStringSize_Product];
extern const uint8_t                           gStringDescSN[CStringSize_SerialNumber];
extern const uint8_t                           gStringDescMicro[CStringSize_MicroController];
extern const uint8_t                           *gStringDescriptor[CbNumStringDescriptor];

#endif  /* _USBD_DESCRIPTOR_HID_H_ */
