/**
 *******************************************************************************
 * @file    usbd_hid.h
 * @brief   HID Function Header for TOSHIBA Cortex M0/M3/M4 Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#ifndef _USBD_HID_H_
#define _USBD_HID_H_

#include "usbd_hw.h"

/* Current Protocol Status */
#define USBD_HID_BOOT_PROTOCOL              (0U)
#define USBD_HID_REPORT_PROTOCOL            (1U)

/* Class request code */
#define USBD_HID_GET_REPORT                 (0x01U)
#define USBD_HID_GET_IDLE                   (0x02U)
#define USBD_HID_GET_PROTOCOL               (0x03U)
#define USBD_HID_SET_REPORT                 (0x09U)
#define USBD_HID_SET_IDLE                   (0x0AU)
#define USBD_HID_SET_PROTOCOL               (0x0BU)

/* definitions of Get_Report and Set_Report */
/* Report Type */
#define USBD_HID_REPORT_TYPE_INPUT          (0x01U)
#define USBD_HID_REPORT_TYPE_OUTPUT         (0x02U)
#define USBD_HID_REPORT_TYPE_FEATURE        (0x03U)

/* definitions of Get Idle */
#define USBD_HID_GET_IDLE_VALUE_H           (0x00U)
#define USBD_HID_GET_IDLE_LENGTH            (0x0001U)

/* definitions of Set Idle */
#define USBD_HID_SET_IDLE_LENGTH            (0x0000U)

/* definitions of Get Protocol */
#define USBD_HID_GET_PROTOCOL_VALUE         (0x0000U)
#define USBD_HID_GET_PROTOCOL_LENGTH        (0x0001U)

/* definitions of Set Protocol */
#define USBD_HID_SET_PROTOCOL_LENGTH        (0x0000U)

/* Number of Report ID */
#define USBD_HID_REPORT_ID_NUM              (1U)

/* Typedef for HID Callback Functions */
typedef void    (*USBD_HID_ConnStat)(bool);
typedef void    (*USBD_HID_Notice)(void);
typedef bool    (*USBD_HID_Report_Req)(uint8_t, uint16_t);
typedef uint8_t (*USBD_HID_GetIdle_Req)(uint8_t);
typedef void    (*USBD_HID_SetIdle_Req)(uint8_t, uint8_t);
typedef uint8_t (*USBD_HID_GetProtocol_Req)(void);
typedef void    (*USBD_HID_SetProtocol_Req)(uint16_t);
typedef void    (*USBD_HID_TrnsData)(uint32_t, uint8_t*, uint16_t);

/**
  * @brief Structure of callback information
  */
typedef struct {
    USBD_HID_ConnStat           pfnConnStat;
    USBD_HID_Notice             pfnSuspend;
    USBD_HID_Notice             pfnResume;
    USBD_HID_Report_Req         pfnGetReport;
    USBD_HID_Report_Req         pfnSetReport;
    USBD_HID_GetIdle_Req        pfnGetIdle;
    USBD_HID_SetIdle_Req        pfnSetIdle;
    USBD_HID_GetProtocol_Req    pfnGetProtocol;
    USBD_HID_SetProtocol_Req    pfnSetProtocol;
    USBD_HID_TrnsData           pfnSendData;
    USBD_HID_TrnsData           pfnCtrlSendData;
    USBD_HID_TrnsData           pfnCtrlRecvData;
} HID_CB_t;

/* HID Initialize */
extern void usbd_hid_init(HID_CB_t*);

/* HID Request Handler */
extern bool usbd_interrupt_HID_req(uint32_t);

/* Other Prototypes */
extern bool USBD_HID_SendData(uint32_t, uint8_t*);
extern bool USBD_HID_CtrlSendData(uint32_t, uint8_t*);
extern bool USBD_HID_CtrlRecvData(uint32_t, uint8_t*);
extern void USBD_HID_Connect(void);
extern void USBD_HID_DisConnect(void);

#endif /* _USBD_HID_H_ */
