/**
 *******************************************************************************
 * @file    usbd_device_request.h
 * @brief   USB Standard Descriptor Header for TOSHIBA Cortext M0/M3/M4 Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#ifndef _USBD_DEVICE_REQUEST_H_
#define _USBD_DEVICE_REQUEST_H_

#include "usbd_descriptor.h"
#include "usbd_hw.h"
#include "usbd_typedefs.h"
/* for bmRequestType Direction */
#define CbmRequestType_Direction_HtoD       0x00U
#define CbmRequestType_Direction_DtoH       0x01U

/* for bmRequestType Type */
#define CbmRequestType_Type_Standard        0x00U
#define CbmRequestType_Type_Class           0x01U
#define CbmRequestType_Type_Vendor          0x02U
#define CbmRequestType_Type_Error           0x03U

/* for bmRequestType Recipient */
#define CbmRequestType_Recipient_Device     0x00U
#define CbmRequestType_Recipient_Interface  0x01U
#define CbmRequestType_Recipient_Endpoint   0x02U
#define CbmRequestType_Recipient_Other      0x03U

/* for wIndex */
#define CwIndex_ZERO                        0x0000U
#define CwIndex_RESERVED_MASK_ENDPOINT      0xFF70U
#define CwIndex_RESERVED_ENDPOINT           0x0000U
#define CwIndex_RESERVED_MASK_INTERFACE     0xFF00U
#define CwIndex_RESERVED_INTERFACE          0x0000U

/* for bRequest */
#define CbRequest_GET_STATUS                0x00U
#define CbRequest_CLEAR_FEATURE             0x01U
#define CbRequest_SET_FEATURE               0x03U
#define CbRequest_SET_ADDRESS               0x05U
#define CbRequest_GET_DESCRIPTOR            0x06U
#define CbRequest_SET_DESCRIPTOR            0x07U
#define CbRequest_GET_CONFIGURATION         0x08U
#define CbRequest_SET_CONFIGURATION         0x09U
#define CbRequest_GET_INTERFACE             0x0AU
#define CbRequest_SET_INTERFACE             0x0BU
#define CbRequest_SYNCH_FRAME               0x0CU

/* for wValue Type  */
#define CwValue_TypeDevice                  CbDescripterType_Device
#define CwValue_TypeDeviceQualifier         CbDescripterType_DeviceQualifer
#define CwValue_TypeConfig                  CbDescripterType_Configuration
#define CwValue_TypeOtherSpeed              CbDescripterType_OtherSpeedConfiguration
#define CwValue_TypeInterface               CbDescripterType_Interface
#define CwValue_TypeEndpoint                CbDescripterType_Endpoint
#define CwValue_TypeString                  CbDescripterType_String
#define CwValue_TypeInterfacePower          CbDescripterType_InterfacePower

#ifdef _USBD_HID_
#define CwValue_TypeHIDDescriptor           0x21U
#define CwValue_TypeHIDReport               0x22U
#endif

/* for  wValue Feature Selector */
#define CwValueSelector_DEVICE_REMOTE_WAKEUP    0x01U
#define CwValueSelector_ENDPOINT_HALT           0x00U
#define CwValueSelector_TEST_MODE               0x02U

/* for clear feature */
#define CwLength_ClearFeature                   0x00U

/* for get configuration */
#define CwValue_GetConfiguration                0x0000U
#define CwLength_GetConfiguration               0x0001U

/* for get descriptor */
#define CwValue_GetDescriptor_IndexDevice           0x00U
/* #define CwValue_GetDescriptor_IndexConfig        user define */
/* #define CwValue_GetDescriptor_IndexString        user define */
#define CwValue_GetDescriptor_IndexDeviceQualifier  0x00U
#define CwValue_GetDescriptor_IndexOtherSpeed       0x00U

#define CwIndex_GetDescriptor_Device                0x00U
#define CwIndex_GetDescriptor_Config                0x00U
/* #define CwIndex_GetDescriptor_String             user define */
#define CwIndex_GetDescriptor_DeviceQualifier       0x00U
#define CwIndex_GetDescriptor_OtherSpeed            0x00U

/* for get interface */
#define CwValue_GetInterface                        0x00U
#define CwLength_GetInterface                       0x01U

/* for  get status */
#define CwValue_GetStatus                           0x00U
#define CwLength_GetStatus                          0x02U

/* for set address */
#define CwValue_SetAddress_MAX                      0x7FU
#define CwLength_SetAddress                         0x00U
#define CDeviceAddressMAX                           CwValue_SetAddress_MAX

/* for  set configuration */
#define CwValue_Reserved                            0x00U
#define CwLength_SetConfiguration                   0x00U

/* for  set feature */
#define CwLength_SetFeature                         0x00U

/* for set interface */
#define CwLength_SetInterface                       0x00U

/* UDC Stage parameters
    Control Read    IDLE => SETUP => DATA => STATUS => IDLE
    Control Write   IDLE => SETUP         => STATUS => IDLE
    Control Write   IDLE => SETUP => DATA => STATUS => IDLE
 */
#define IDLE_STAGE                  0x00U   /* Idle Stage   */
#define SETUP_STAGE                 0x01U   /* Setup Stage  */
#define DATA_STAGE                  0x02U   /* Data Stage   */
#define STATUS_STAGE                0x03U   /* Status Stage */

/* for bmRequestType */
typedef union {
    uint8_t bmRequestType;
    struct {
        uint8_t Recipient:5;    /* <4:0>        */
        uint8_t Req_Type:2;     /* <6:5>        */
        uint8_t Direction:1;    /* <7>          */
    } Bit;
} bmRequestType_t;

/* for wValue */
typedef union {                 /* for Get Descriptor  */
    uint16_t wValue;
    struct {
        uint16_t Index:8;       /* <7:0>               */
        uint16_t Type:8;        /* <15:8>              */
    } Bit;
} wValue_GetDescriptor_t;

typedef union {                 /* for  Set Configuration    */
    uint16_t wValue;
    struct {
        uint16_t Configuration:8;       /* <7:0> match from config desc */
        uint16_t Reserved:8;            /* <15:8>                       */
    } Bit;
} wValue_SetConfiguration_t;

/* for  wIndex  */
typedef struct {
    uint16_t Endpoint:4;        /* <3:0>    */
    uint16_t Reserved1:3;       /* <6:4>    */
    uint16_t Direction:1;       /* <7>      */
    uint16_t Reserved2:8;       /* <15:8>   */
} wIndexEndpoint_t;

typedef struct {
    uint16_t Number:8;          /* <7:0>    */
    uint16_t Reserved:8;        /* <15:8>   */
} wIndexInterface_t;

typedef struct {                /* Set Feature  */
    uint16_t Reserved:8;        /* <7:0>        */
    uint16_t Test:8;            /* 15:8>        */
} wIndexTestSelector_t;

typedef union {
    uint16_t wIndex;
    wIndexEndpoint_t Endpoint;
    wIndexInterface_t Interface;
    wIndexTestSelector_t Test;
} wIndex_t;

/* for USB Device Request */
typedef struct {
    bmRequestType_t bmRequestType;
    uint8_t bRequest;
    uint16_t wValue;
    wIndex_t wIndex;
    uint16_t wLength;
} SetupDataFormat_t;

/* for Get Status   */
typedef struct {
    uint16_t SelfPowered:1;     /* <0>          */
    uint16_t RemoteWakeup:1;    /* <1>          */
    uint16_t Reserved:14;       /* <15:2>       */
} GetStatusDevice_t;

/* for  Get Status  (Data) */
typedef struct {
    uint16_t Reserved:16;       /* <15:0>       */
} GetStatusInterface_t;

typedef struct {
    uint16_t Halt:1;            /* <0>          */
    uint16_t Reserved:15;       /* <15:1>       */
} GetStatusEndpoint_t;

typedef union {
    uint16_t Data;
    GetStatusDevice_t Device;
    GetStatusInterface_t Interface;
    GetStatusEndpoint_t Endpoint;
} GetStatus_t;

extern void usbd_initialize_standard_class_work_data(void);
extern bool usbd_interrupt_setup_standard(uint32_t request);
extern void usbd_device_request_update_current_config(void);
extern void usbd_set_epx_feature(USBD_EPx EPx, USBD_EPCMD Cmd);

#endif  /* _USBD_DEVICE_REQUEST_H_ */
