/**
 *******************************************************************************
 * @file    usbd_typedefs.h
 * @brief   type define for UDC2 register for TOSHIBA 'TMPM066' Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* 'TMPM066' only has EP0 to EP4 */

#ifndef _USBD_TYPEDEFS_H_
#define _USBD_TYPEDEFS_H_

#include "usbd_device_request.h"
#include "stdbool.h"

#ifndef NULL
#define NULL ((void*)0)
#endif

/* for UDFS2ADR */
typedef union {
    uint32_t All;
    struct {
        uint32_t Device_Addr:7;     /* <6:0>  RW        */
        uint32_t Reserved1:1;       /* <7>    -         */
        uint32_t Device_State:3;    /* <10:8> RW        */
        uint32_t Suspend:1;         /* <11>   RO        */
        uint32_t Current_Speed:2;   /* <13:12>RO        */
        uint32_t EP_BiDir_Mode:1;   /* <14>   RW        */
        uint32_t Stage_Error:1;     /* <15>   RO        */
        uint32_t Reserved2:16;      /* <31:16>-         */
    } Bit;
} UDC2_ADDR_t;

/* for UDFS2BRQ */
typedef union {
    uint32_t All;
    struct {
        uint32_t Recipient:5;   /* <4:0>  RO    */
        uint32_t Req_type:2;    /* <6:5>  RO    */
        uint32_t Dir:1;         /* <7>    RO    */
        uint32_t Request:8;     /* <15:8> RO    */
        uint32_t Reserved1:16;  /* <31:16>-     */
    } Bit;
} UDC2_BREQ_BMREQTYPE_t;

/* for UDFS2WVL */
typedef union {
    uint32_t All;
    struct {
        uint32_t wValue_l:8;    /* <7:0>  RO    */
        uint32_t wValue_h:8;    /* <15:8> RO    */
        uint32_t Reserved1:16;  /* <31:16>-     */
    } Bit;
    struct {
        uint32_t wValue:16;     /* <15:0> RO    */
        uint32_t Reserved1:16;  /* <31:16>-     */
    } Bit16;
} UDC2_WVALUE_t;

/* for UDFS2WIDX */
typedef union {
    uint32_t All;
    struct {
        uint32_t wIndex_l:8;    /* <7:0>  RO    */
        uint32_t wIndex_h:8;    /* <15:8> RO    */
        uint32_t Reserved1:16;  /* <31:16>-     */
    } Bit;
    struct {
        uint32_t wIndex:16;     /* <15:0> RO    */
        uint32_t Reserved1:16;  /* <31:16>-     */
    } Bit16;
} UDC2_WINDEX_t;

/* for UDFS2WLGTH */
typedef union {
    uint32_t All;
    struct {
        uint32_t wLength_l:8;   /* <7:0>  RO    */
        uint32_t wLength_h:8;   /* <15:8> RO    */
        uint32_t Reserved1:16;  /* <31:16>-     */
    } Bit;
    struct {
        uint32_t wLength:16;    /* <15:0> RO    */
        uint32_t Reserved1:16;  /* <31:16> W0   */
    } Bit16;
} UDC2_WLENGTH_t;

/* for UDFS2INTEP */
typedef union {
    uint32_t All;
    struct {
        uint32_t Reserved1:1;   /* <0>    W0    */
        uint32_t i_ep1:1;       /* <1>    RW    */
        uint32_t i_ep2:1;       /* <2>    RW    */
        uint32_t i_ep3:1;       /* <3>    RW    */
        uint32_t i_ep4:1;       /* <4>    RW    */
        uint32_t Reserved2:27;  /* <31:5> W0    */
    } Bit;
} UDC2_INTEP_t;


/* for UDFS2INTEPMSK */
typedef union {
    uint32_t All;
    struct {
        uint32_t m_ep0:1;       /* <0>    RW    */
        uint32_t m_ep1:1;       /* <1>    RW    */
        uint32_t m_ep2:1;       /* <2>    RW    */
        uint32_t m_ep3:1;       /* <3>    RW    */
        uint32_t m_ep4:1;       /* <4>    RW    */
        uint32_t Reserved1:27;  /* <31:5> W0    */
    } Bit;
} UDC2_INTEPMASK_t;

/* for UDFS2INTRX0 */
typedef union {
    uint32_t All;
    struct {
        uint32_t Rx_d0_ep0:1;   /* <0>    RW    */
        uint32_t Rx_d0_ep1:1;   /* <1>    RW    */
        uint32_t Rx_d0_ep2:1;   /* <2>    RW    */
        uint32_t Rx_d0_ep3:1;   /* <3>    RW    */
        uint32_t Rx_d0_ep4:1;   /* <4>    RW    */
        uint32_t Reserved1:27;  /* <31:5> W0    */
    } Bit;
} UDC2_INTRX0_t;

/* for UDFS2INTNAK */
typedef union {
    uint32_t All;
    struct {
        uint32_t Reserved1:1;   /* <0>    W0    */
        uint32_t I_ep1:1;       /* <1>    RW    */
        uint32_t I_ep2:1;       /* <2>    RW    */
        uint32_t I_ep3:1;       /* <3>    RW    */
        uint32_t I_ep4:1;       /* <4>    RW    */
        uint32_t Reserved2:27;  /* <31:5> W0    */
    } Bit;
} UDC2_INTNAK_t;

/* for UDFS2INTNAKMSK */
typedef union {
    uint32_t All;
    struct {
        uint32_t Reserved1:1;   /* <0>    -     */
        uint32_t M_EP1:1;       /* <1>    RW    */
        uint32_t M_EP2:1;       /* <2>    RW    */
        uint32_t M_EP3:1;       /* <3>    RW    */
        uint32_t M_EP4:1;       /* <4>    RW    */
        uint32_t Reserved2:27;  /* <31:5> -     */
    } Bit;
} UDC2_INTNAK_MASK_t;

/* for UDFS2EP0MSZ */
typedef union {
    uint32_t All;
    struct {
        uint32_t Max_Packet:7;  /* <6:0>   RW   */
        uint32_t Reserved1:5;   /* <11:7>  -    */
        uint32_t Dset:1;        /* <12>    RW   */
        uint32_t Reserved2:2;   /* <14:13> -    */
        uint32_t Tx_0data:1;    /* <15>    RO   */
        uint32_t Reserved3:16;  /* <31:16> -    */
    } Bit;
} UDC2_EP0_MAXSIZE_t;

/* for UD2EPxMSZ */
typedef union {
    uint32_t All;
    struct {
        uint32_t Max_Packet:11; /* <10:0>  RW   */
        uint32_t Reserved1:1;   /* <11>    -    */
        uint32_t Dset:1;        /* <12>    RW   */
        uint32_t Reserved2:2;   /* <14:13> -    */
        uint32_t Tx_0data:1;    /* <15>    RO   */
        uint32_t Reserved3:16;  /* <31:16> -    */
    } Bit;
} UDC2_EPxMAXPACKETSIZE_t;


#define CUDC2_TRUE  true
#define CUDC2_FALSE false

/* for UD2ADR */
#define CUD2ADR_B_DEV_ADR_INIT              0U
#define CUD2ADR_B_STATE_INIT                0U
#define CUD2ADR_B_STATE_DEFAULT             1U
#define CUD2ADR_B_STATE_ADDRESSED           2U
#define CUD2ADR_B_STATE_CONFIGURED          4U

#define CUDC2ADDR_FULLSPEED                 1U
#define CUDC2ADDR_HIGHSPEED                 2U

/* for UD2BRQ */
#define CUD2BRQ_B_ReqType_STANDARD              CbmRequestType_Type_Standard
#define CUD2BRQ_B_ReqType_CLASS                 CbmRequestType_Type_Class
#define CUD2BRQ_B_ReqType_VENDOR                CbmRequestType_Type_Vendor

#define CUD2BRQ_B_DIR_GET                       CbmRequestType_Direction_DtoH
#define CUD2BRQ_B_DIR_SET                       CbmRequestType_Direction_HtoD

#define CUD2BRQ_B_REQUEST_GET_STATUS            CbRequest_GET_STATUS
#define CUD2BRQ_B_REQUEST_CLEAR_FEATURE         CbRequest_CLEAR_FEATURE
#define CUD2BRQ_B_REQUEST_SET_FEATURE           CbRequest_SET_FEATURE
#define CUD2BRQ_B_REQUEST_SET_ADDRESS           CbRequest_SET_ADDRESS
#define CUD2BRQ_B_REQUEST_GET_DESCRIPTOR        CbRequest_GET_DESCRIPTOR
#define CUD2BRQ_B_REQUEST_SET_DESCRIPTOR        CbRequest_SET_DESCRIPTOR
#define CUD2BRQ_B_REQUEST_GET_CONFIGURATION     CbRequest_GET_CONFIGURATION
#define CUD2BRQ_B_REQUEST_SET_CONFIGURATION     CbRequest_SET_CONFIGURATION
#define CUD2BRQ_B_REQUEST_GET_INTERFACE         CbRequest_GET_INTERFACE
#define CUD2BRQ_B_REQUEST_SET_INTERFACE         CbRequest_SET_INTERFACE
#define CUD2BRQ_B_REQUEST_SYNCH_FRAME           CbRequest_SYNCH_FRAME

#endif  /* _USBD_TYPEDEFS_H_ */
