/**
 *******************************************************************************
 * @file    usbd_var.h
 * @brief   USB Common Variables Header for TOSHIBA 'TMPM066' Device Series
 * @version V1.000
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#ifndef _USBD_VAR_H_
#define _USBD_VAR_H_

#include "tx00_common.h"
#include "usbd_device_request.h"
#include "usbd_typedefs.h"

/* 32bit union structure    */
typedef union {
    uint32_t All;
    struct {
        uint32_t b0:1;
        uint32_t b1:1;
        uint32_t b2:1;
        uint32_t b3:1;
        uint32_t b4:1;
        uint32_t b5:1;
        uint32_t b6:1;
        uint32_t b7:1;

        uint32_t b8:1;
        uint32_t b9:1;
        uint32_t b10:1;
        uint32_t b11:1;
        uint32_t b12:1;
        uint32_t b13:1;
        uint32_t b14:1;
        uint32_t b15:1;

        uint32_t b16:1;
        uint32_t b17:1;
        uint32_t b18:1;
        uint32_t b19:1;
        uint32_t b20:1;
        uint32_t b21:1;
        uint32_t b22:1;
        uint32_t b23:1;

        uint32_t b24:1;
        uint32_t b25:1;
        uint32_t b26:1;
        uint32_t b27:1;
        uint32_t b28:1;
        uint32_t b29:1;
        uint32_t b30:1;
        uint32_t b31:1;
    } Bit;
} USBD_BIT32_t;

#define CUSBD_BIT_FALSE         0U
#define CUSBD_BIT_TRUE          1U

#define UD2EPxMSZ_B_TX_0DATA_T  CUSBD_BIT_TRUE  /* during transmit      */
#define UD2EPxMSZ_B_TX_0DATA_F  CUSBD_BIT_FALSE /* end of transmit      */
#define UD2EPxMSZ_B_DSET_T      CUSBD_BIT_TRUE  /* exist data           */
#define UD2EPxMSZ_B_DSET_F      CUSBD_BIT_FALSE /* no data              */

/* Number of Endpoint UDC[0-4] for gEPxPAYLOAD_SIZE */
#define CNumEndpointSupport     0x04U   /* EP0,1,2,3 */

#define gEP0Payload_Size        gEPxPayload_Size[USBD_EP0]
#define gEP1Payload_Size        gEPxPayload_Size[USBD_EP1]
#define gEP2Payload_Size        gEPxPayload_Size[USBD_EP2]
#define gEP3Payload_Size        gEPxPayload_Size[USBD_EP3]
#define gEP4Payload_Size        gEPxPayload_Size[USBD_EP4]


/* for gEPxStallFeatureFlag */
#define CEPxStallFeature_AllClear   0x0000U
#define CEPxStallFeature_MASK       0x0001U
#define CEPxStallFeature_Clear      0x0000U

#define CFIFO_BUFSIZE               0x200U

/* Endpoint FIFO Access */
extern uint32_t gEP0RWFIFO_RemainSize;
extern uint8_t *gEP0RWFIFO_StartAddress;

extern uint32_t gEPxWriteFIFO_RemainSize;
extern uint8_t *gEPxWriteFIFO_StartAddress;
extern uint8_t gEPxWriteFIFO_Buffer[CFIFO_BUFSIZE];

extern uint32_t gEPxReadFIFO_RemainSize;
extern uint8_t *gEPxReadFIFO_StartAddress;
extern uint8_t gEPxReadFIFO_Buffer[CFIFO_BUFSIZE];

extern uint32_t gEPxPayload_Size[CNumEndpointSupport];
extern uint32_t gEPxConfigArray[CNumEndpointSupport];

extern USBD_BIT32_t gEPxStallFeatureFlag;
#define fEP0StallFeature            gEPxStallFeatureFlag.Bit.b0
#define fEP1StallFeature            gEPxStallFeatureFlag.Bit.b1
#define fEP2StallFeature            gEPxStallFeatureFlag.Bit.b2
#define fEP3StallFeature            gEPxStallFeatureFlag.Bit.b3
#define fEP4StallFeature            gEPxStallFeatureFlag.Bit.b4

#define CEPxStallFeature_OFF        0U      /* -            */
#define CEPxStallFeature_ON         1U      /* Halt         */

extern UDC2_ADDR_t gUDC2Addr;       /* Current Device State       */
extern UDC2_ADDR_t gUDC2AddrBuf;    /* Buffer of Current Device State     */
#define CUD2ADDR_INIT               0x0100U
#define CgUD2ADDR_INIT              CUD2ADDR_INIT
#define gDeviceAddr                 gUDC2Addr.Bit.Device_Addr
#define gDeviceAddrBuf              gUDC2AddrBuf.Bit.Device_Addr
#define CDEVIECE_ADDRESS_INIT       CUD2ADR_B_DEV_ADR_INIT

#define gDeviceState                gUDC2Addr.Bit.Device_State
#define gDeviceStateBuf             gUDC2AddrBuf.Bit.Device_State

#define CDEVICE_STATE_DEFAULT       CUD2ADR_B_STATE_DEFAULT
#define CDEVICE_STATE_ADDRESSED     CUD2ADR_B_STATE_ADDRESSED
#define CDEVICE_STATE_CONFIGURED    CUD2ADR_B_STATE_CONFIGURED

/* for  USB Device Request */
extern SetupDataFormat_t gSetupFormatData;
#define g_bmRequestType     gSetupFormatData.bmRequestType.bmRequestType
#define f_bmDirection       gSetupFormatData.bmRequestType.Bit.Direction
#define g_RequestType       gSetupFormatData.bmRequestType.Bit.Req_Type
#define g_Recipient         gSetupFormatData.bmRequestType.Bit.Recipient
#define g_bRequest          gSetupFormatData.bRequest
#define g_wValue            gSetupFormatData.wValue
#define g_wIndex            gSetupFormatData.wIndex.wIndex
#define g_wLength           gSetupFormatData.wLength

extern uint32_t g_USB_Stage;

#endif  /* _USBD_VAR_H_ */
