/**
 *******************************************************************************
 * @file    usbd_hw_com.c
 * @brief   USB H/W Common Code for TOSHIBA 'TMPM066' Device Series
 * @version V0.100
 * @date    2015/09/11
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 *
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

#include "usbd_hw.h"
#include "tmpm066_gpio.h" 

/**
  * @brief Software delay loop
  */
#define SOFTWARE_DELAY  0x20000U;

/**
  * @brief  Wait 1ms
  * @param  None
  * @retval None
  */
void usbd_wait_1ms(void)
{
    uint32_t delay = SOFTWARE_DELAY;
    while (delay) {
        delay--;
    }
    return;
}

/**
  * @brief  Config the clock and power of USBD
  * @param  None
  * @retval None
  */
void Config_USB(void)
{
    USBD_PowerCtrl pwr = { 0U };

    /* know issue: for M066 use FSYSENA, for M365 use USBCTL, the bit position is also different. */
   
    TSB_CG->FSYSENA |= 0x20000U;    /* enable USB Clock */    
    __NOP();
    __NOP();
    __NOP();
    TSB_CG->EXTENDO0 |= 0x01U;    /* enable USB clock supply */

    /*USBON pin config*/
    /* for M066 EVB (EBD007 - 083A), make JP4/5 off, JP1/2 on */
    /*  then no need to control the pull-up resistor on D+ */
    // modify it later after schematic is ready
    /* set Vbus as input */
    GPIO_SetInput(GPIO_PC, GPIO_BIT_5);
    GPIO_SetInputEnableReg(GPIO_PC, GPIO_BIT_5, ENABLE);
#if 0 
    /* pin PA0 control the pull up of D+, must be set output '1' */
    GPIO_SetOutput(GPIO_PA, GPIO_BIT_0);
    GPIO_WriteDataBit(GPIO_PA, GPIO_BIT_0, GPIO_BIT_VALUE_1);
#endif


    USBD_SetINTMask(USBD_INT_USB_RESET_END, ENABLE);
    USBD_SetINTMask(USBD_INT_USB_RESET, ENABLE);

    /*  UDPWCTL Power Reset and            */
    /*      PHY Reset & Suspend: 1ms       */
    pwr = USBD_GetPowerCtrlStatus();
    pwr.Bit.PW_Resetb = 0U;
    pwr.Bit.PHY_Resetb = 0U;
    pwr.Bit.PHY_Suspend = 1U;
    USBD_SetPowerCtrl(pwr);
    usbd_wait_1ms();

    /* PHY Reset off : 1ms                  */
    pwr = USBD_GetPowerCtrlStatus();
    pwr.Bit.PHY_Resetb = 1U;
    pwr.Bit.PHY_Suspend = 1U;
    USBD_SetPowerCtrl(pwr);
    usbd_wait_1ms();

    /*  PHY Suspend off : 1ms              */
    pwr = USBD_GetPowerCtrlStatus();
    pwr.Bit.PHY_Suspend = 0U;
    USBD_SetPowerCtrl(pwr);
    usbd_wait_1ms();

    usbd_wait_1ms();

    /*  UDPWCTL Power Reset Off: 1ms        */
    pwr = USBD_GetPowerCtrlStatus();
    pwr.Bit.PW_Resetb = 1U;
    USBD_SetPowerCtrl(pwr);
    usbd_wait_1ms();
    usbd_wait_1ms();
    pwr = USBD_GetPowerCtrlStatus();

    /* clear pending UDC2 interrupt and disable INT for SOF and NAK */
    USBD_WriteUDC2Reg(UDC2_INT, 0x90FFU);

    USBD_SetEPCMD(USBD_EP0, USBD_CMD_ALL_EP_INVALID);
    USBD_SetEPCMD(USBD_EP0, USBD_CMD_USB_READY);

    NVIC_EnableIRQ(INTUSB_IRQn);

    // VBUS, in M066 use Wakeup interrupt
    NVIC_EnableIRQ(INTUSBWKUP_IRQn);

    return;
}

/* EOC */
