/**
 *******************************************************************************
 * @file    lcd.c
 * @brief   The driver of LCD for the
 *           TOSHIBA 'TMPM066' Device Series 
 * @version V0.100
 * @date    2015/10/23
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "lcd.h"
#include <string.h>


#define LCD_DATA    (TSB_PA->DATA)
#define LCDE        (TSB_PF_DATA_PF1)
#define LCDRW       (TSB_PF_DATA_PF2)
#define LCDRS       (TSB_PF_DATA_PF3)

#define LCD_WRITE   0UL
#define LCD_READ    1UL

void Delay(uint32_t time);

/*******************************************************************************
* Function Name  : E_Pulse
* Description    : Generation a pulse enable the LCD.
* Input          : None.
* Return         : None.
*******************************************************************************/
void E_Pulse(void)
{
    // set E high
    LCDE = 1;
    Delay(20);
    // set E low
    LCDE = 0;
    Delay(20);
}

/*******************************************************************************
* Function Name  : Set_Data
* Description    : transfer data to LCD
* Input          : data --- The data will transfer to LCD
* Return         : None.
*******************************************************************************/
void Set_Data(unsigned char data)
{
    LCD_DATA = data;
}

/*******************************************************************************
* Function Name  : Send_To_LCD
* Description    : send command or data to LCD
* Input          : data --- command or data
*                  type --- LCD_COMMAND or LCD_CHARACTER
* Return         : None.
*******************************************************************************/
void Send_To_LCD(unsigned char data, unsigned char type)
{
    // enable write
    LCDRW = LCD_WRITE;
    Delay(20);
    Set_Data(data);
    // set RS port to set command mode or data
    if (type == LCD_COMMAND)
        LCDRS = 0;
    else
        LCDRS = 1;
    E_Pulse();
}

/*******************************************************************************
* Function Name  : Send_LCD_Text
* Description    : Send the string to LCD
* Input          : str --- pointer of the string
* Return         : None.
*******************************************************************************/
void Send_LCD_Text(char *str)
{
    unsigned char i;

    //Send_To_LCD(CUR_HOME,LCD_COMMAND);
    //Delay(1520);

    /* loop over string and send each character */
    for (i = 0; i < strlen(str); i++) {
        Send_To_LCD(str[i], LCD_CHARACTER);
    }
    for (; i < 16; i++)
        Send_To_LCD(' ', LCD_CHARACTER);
}

void Send_LCD_Text2(char *str, char *str1)
{
    unsigned char i, j;

    //Send_To_LCD(CUR_HOME,LCD_COMMAND);
    //Delay(1520);

    /* loop over string and send each character */
    for (i = 0; i < strlen(str); i++) {
        Send_To_LCD(str[i], LCD_CHARACTER);
    }
    for (j = 0; j < strlen(str1); j++) {
        Send_To_LCD(str1[j], LCD_CHARACTER);
    }
    for (; j + i < 16; j++)
        Send_To_LCD(' ', LCD_CHARACTER);
}

/*******************************************************************************
* Function Name  : LCD_IO
* Description    : Config LCD to IO
* Input          : data --- The data will transfer to LCD
* Return         : None.
*******************************************************************************/

void LCD_IO(void)
{
    TSB_PA->CR = (uint32_t) 0xFF;
    TSB_PA->PUP = (uint32_t) 0xFF;
    TSB_PF->CR |= (uint32_t) 0xE0;
    TSB_PF->PUP |= (uint32_t) 0xE0;
}

/*******************************************************************************
* Function Name  : LCD_Configuration
* Description    : Configures LCD
* Input          : None.
* Return         : None.
*******************************************************************************/
void LCD_Configuration(void)
{
    LCD_IO();

    LCDE = 0;
    LCDRW = 0;
    LCDRS = 0;

    Send_To_LCD(FUNCTION_SET | CONFIG_8BIT_BUS, LCD_COMMAND);

    Send_To_LCD(FUNCTION_SET | CONFIG_8BIT_BUS, LCD_COMMAND);

    Send_To_LCD(FUNCTION_SET | CONFIG_8BIT_BUS, LCD_COMMAND);

    Send_To_LCD(FUNCTION_SET | CONFIG_8BIT_BUS | CONFIG_2_LINES | CONFIG_5X7_DOT, LCD_COMMAND);

    // enable display
    Send_To_LCD(DISP_ON, LCD_COMMAND);

    // clear display
    Send_To_LCD(CLR_DISP, LCD_COMMAND);
    Delay(3000);
}

void Delay(uint32_t time)
{
    volatile uint32_t i = 0;

    for (i = 0; i < time * 10U; ++i);
}
