/**
 ******************************************************************************
 * @file     led.c
 * @brief    LED driver for the TOSHIBA 'TMPM066' Device Series
 * @version V2.0.2.1
 * @date    2015/09/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 ******************************************************************************
 */

/** include files **/

#include "led.h"

/*************************************************************************
 * Function Name: LED_Init
 * Parameters:None
 * Return:None  
 * Description: Init LED ports
 *************************************************************************/
void LED_Init(void)
{
    /*Set PB bit0~ 1 as output */
    /* for M066, PB0 = pin6, PB1 = pin5 */
    GPIO_SetOutput(GPIO_PB, GPIO_BIT_0 | GPIO_BIT_1);
    
    /* for debug */
    GPIO_WriteDataBit(GPIO_PB, GPIO_BIT_0 | GPIO_BIT_1 , GPIO_BIT_VALUE_1 );  
    GPIO_WriteDataBit(GPIO_PB, GPIO_BIT_0 | GPIO_BIT_1 , GPIO_BIT_VALUE_0 ); 
    
}

/*************************************************************************
 * Function Name: LED_On
 * Parameters:LED number, choose from LED0, LED1 or LED_ALL.
 * Return:None  
 * Description: The choosen Led is ON.
 *************************************************************************/

void LED_On(uint8_t led)
{
    volatile uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PB);
    tmp |= led & 0x0F;
    GPIO_WriteData(GPIO_PB, tmp);
}

/*************************************************************************
 * Function Name: LED_Off
 * Parameters:LED number, choose from LED0, LED1 or LED_ALL.
 *
 * Return:None  
 *
 * Description: The choosen Led is Off.
 *
 *************************************************************************/
void LED_Off(uint8_t led)
{
    volatile uint8_t tmp;
    tmp = GPIO_ReadData(GPIO_PB);
    tmp &= (uint8_t) (~led) & 0x0F;
    GPIO_WriteData(GPIO_PB, tmp);
}
