/**
 ******************************************************************************
 * @file     sw.c
 * @brief    SW driver for the TOSHIBA 'TMPM066' Device Series
 * @version V2.0.2.1
 * @date    2015/09/09
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LISENCE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA CORPORATION 2015 All rights reserved
 ******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "sw.h"

/*******************************************************************************
* Function Name  : SW_Init. use PB2 to PB3 as SW input.
* Description    : Initialize the GPIO to SW 
* Input          : None 
* Return         : None.
*******************************************************************************/
void SW_Init(void)
{
    /* for M066, PB3 = pin3, PB2 = pin4 */    
    GPIO_SetInput(GPIO_PB, GPIO_BIT_2 | GPIO_BIT_3);
    GPIO_SetPullUp(GPIO_PB, GPIO_BIT_2 | GPIO_BIT_3, ENABLE);
        
}

/*******************************************************************************
* Function Name  : SW_Get
* Description    : Get SW Value
* Input          : SW (choose from SW0 ~ SW1).
* Return         : 1: SW is pressed, 0: SW isn't pressed.
*******************************************************************************/
uint8_t SW_Get(uint8_t sw)
{
    uint8_t tmp = 0U;
    switch (sw) {
    case SW0:
        if (GPIO_ReadDataBit(GPIO_PB, GPIO_BIT_2) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    case SW1:
        if (GPIO_ReadDataBit(GPIO_PB, GPIO_BIT_3) == 0U) {
            tmp = 1U;
        } else {
            /*Do nothing */
        }
        break;
    }
    return tmp;

}
